@@ -16,89 +16,141 @@
 #include "k3bexternalbinmanager.h"
 #include "k3bglobals.h"
 
-#include <KConfigGroup>
-#include <KDebug>
-#include <kdeversion.h>
-#include <kde_file.h>
-#include <KProcess>
-#include <KStandardDirs>
+#include <KConfigCore/KConfigGroup>
+#include <KCoreAddons/KProcess>
 
-#include <QDir>
-#include <QFileInfo>
-#include <QFile>
-#include <QRegExp>
+#include <QtCore/QDebug>
+#include <QtCore/QDir>
+#include <QtCore/QFileInfo>
+#include <QtCore/QFile>
+#include <QtCore/QtGlobal>
+#include <QtCore/QRegExp>
 
 #ifndef Q_OS_WIN32
 #include <unistd.h>
 #include <sys/stat.h>
 #include <stdlib.h>
+#include <grp.h>
 #endif
 
 
 namespace {
     bool compareVersions( const K3b::ExternalBin* bin1, const K3b::ExternalBin* bin2 )
     {
-        return bin1->version > bin2->version;
+        return bin1->version() > bin2->version();
     }
 
     const int EXECUTE_TIMEOUT = 5000; // in seconds
 }
 
 
-QString K3b::ExternalBinManager::m_noPath = "";
-
-
 // ///////////////////////////////////////////////////////////
 //
 // K3BEXTERNALBIN
 //
 // ///////////////////////////////////////////////////////////
 
-K3b::ExternalBin::ExternalBin( K3b::ExternalProgram* p )
-    : m_program(p)
+class K3b::ExternalBin::Private
 {
+public:
+    Private( ExternalProgram& pr, const QString& pa )
+        : program( pr ), path( pa ) {}
+
+    ExternalProgram& program;
+    QString path;
+    QString needGroup;
+    Version version;
+    QString copyright;
+    QStringList features;
+};
+
+K3b::ExternalBin::ExternalBin( ExternalProgram& program, const QString& path )
+    : d( new Private( program, path ) )
+{
+}
+
+
+K3b::ExternalBin::~ExternalBin()
+{
+    delete d;
+}
+
+void K3b::ExternalBin::setVersion( const Version& version )
+{
+    d->version = version;
+}
+
+const K3b::Version& K3b::ExternalBin::version() const
+{
+    return d->version;
+}
+
+void K3b::ExternalBin::setNeedGroup( const QString& name )
+{
+    d->needGroup = name;
+}
+
+const QString& K3b::ExternalBin::needGroup() const
+{
+    return d->needGroup;
+}
+
+void K3b::ExternalBin::setCopyright( const QString& copyright )
+{
+    d->copyright = copyright;
+}
+
+const QString& K3b::ExternalBin::copyright() const
+{
+    return d->copyright;
 }
 
 
 bool K3b::ExternalBin::isEmpty() const
 {
-    return !version.isValid();
+    return !d->version.isValid();
+}
+
+
+const QString& K3b::ExternalBin::path() const
+{
+    return d->path;
 }
 
 
 QString K3b::ExternalBin::name() const
 {
-    return m_program->name();
+    return d->program.name();
 }
 
 
 bool K3b::ExternalBin::hasFeature( const QString& f ) const
 {
-    return m_features.contains( f );
+    return d->features.contains( f );
 }
 
 
 void K3b::ExternalBin::addFeature( const QString& f )
 {
-    m_features.append( f );
+    d->features.append( f );
 }
 
 
 QStringList K3b::ExternalBin::userParameters() const
 {
-    return m_program->userParameters();
+    return d->program.userParameters();
 }
 
 
 QStringList K3b::ExternalBin::features() const
 {
-    return m_features;
+    return d->features;
 }
 
 
-K3b::ExternalProgram* K3b::ExternalBin::program() const
+K3b::ExternalProgram& K3b::ExternalBin::program() const
 {
-    return m_program;
+    return d->program;
 }
 
 
@@ -110,37 +162,51 @@ K3b::ExternalProgram* K3b::ExternalBin::program() const
 // ///////////////////////////////////////////////////////////
 
 
+class K3b::ExternalProgram::Private
+{
+public:
+    Private( const QString& n )
+        : name( n ) {}
+
+    QString name;
+    QStringList userParameters;
+    QList<const ExternalBin*> bins;
+    QString defaultBin;
+};
+
+
 K3b::ExternalProgram::ExternalProgram( const QString& name )
-    : m_name( name )
+    : d( new Private( name ) )
 {
 }
 
 
 K3b::ExternalProgram::~ExternalProgram()
 {
-    qDeleteAll( m_bins );
+    qDeleteAll( d->bins );
+    delete d;
 }
 
 
 const K3b::ExternalBin* K3b::ExternalProgram::mostRecentBin() const
 {
-    if ( m_bins.isEmpty() ) {
+    if ( d->bins.isEmpty() ) {
         return 0;
     }
     else {
-        return m_bins.first();
+        return d->bins.first();
     }
 }
 
 
 const K3b::ExternalBin* K3b::ExternalProgram::defaultBin() const
 {
-    if( m_bins.size() == 1 ) {
-        return m_bins.first();
+    if( d->bins.size() == 1 ) {
+        return d->bins.first();
     }
     else {
-        for( QList<const K3b::ExternalBin*>::const_iterator it = m_bins.constBegin(); it != m_bins.constEnd(); ++it ) {
-            if( ( *it )->path == m_defaultBin ) {
+        for( QList<const K3b::ExternalBin*>::const_iterator it = d->bins.constBegin(); it != d->bins.constEnd(); ++it ) {
+            if( ( *it )->path() == d->defaultBin ) {
                 return *it;
             }
         }
@@ -151,26 +217,33 @@ const K3b::ExternalBin* K3b::ExternalProgram::defaultBin() const
 
 void K3b::ExternalProgram::addBin( K3b::ExternalBin* bin )
 {
-    if( !m_bins.contains( bin ) ) {
-        m_bins.append( bin );
+    if( !d->bins.contains( bin ) ) {
+        d->bins.append( bin );
 
         // the first bin in the list is always the one used
         // so we default to using the newest one
-        qSort( m_bins.begin(), m_bins.end(), compareVersions );
+        qSort( d->bins.begin(), d->bins.end(), compareVersions );
 
         const ExternalBin* defBin = defaultBin();
-        if ( !defBin || bin->version > defBin->version ) {
+        if ( !defBin || bin->version() > defBin->version() ) {
             setDefault( bin );
         }
     }
 }
 
 
+void K3b::ExternalProgram::clear()
+{
+    qDeleteAll(d->bins);
+    d->bins.clear();
+}
+
+
 void K3b::ExternalProgram::setDefault( const K3b::ExternalBin* bin )
 {
-    for( QList<const K3b::ExternalBin*>::const_iterator it = m_bins.constBegin(); it != m_bins.constEnd(); ++it ) {
+    for( QList<const K3b::ExternalBin*>::const_iterator it = d->bins.constBegin(); it != d->bins.constEnd(); ++it ) {
         if( *it == bin ) {
-            m_defaultBin = (*it)->path;
+            d->defaultBin = (*it)->path();
             break;
         }
     }
@@ -179,14 +252,44 @@ void K3b::ExternalProgram::setDefault( const K3b::ExternalBin* bin )
 
 void K3b::ExternalProgram::setDefault( const QString& path )
 {
-    m_defaultBin = path;
+    d->defaultBin = path;
+}
+
+
+QList<const K3b::ExternalBin*> K3b::ExternalProgram::bins() const
+{
+    return d->bins;
+}
+
+
+bool K3b::ExternalProgram::supportsUserParameters() const
+{
+    return true;
 }
 
 
 void K3b::ExternalProgram::addUserParameter( const QString& p )
 {
-    if( !m_userParameters.contains( p ) )
-        m_userParameters.append(p);
+    if( !d->userParameters.contains( p ) )
+        d->userParameters.append(p);
+}
+
+
+void K3b::ExternalProgram::setUserParameters( const QStringList& list )
+{
+    d->userParameters = list;
+}
+
+
+QStringList K3b::ExternalProgram::userParameters() const
+{
+    return d->userParameters;
+}
+
+
+QString K3b::ExternalProgram::name() const
+{
+    return d->name;
 }
 
 
@@ -194,7 +297,7 @@ void K3b::ExternalProgram::addUserParameter( const QString& p )
 QString K3b::ExternalProgram::buildProgramPath( const QString& dir, const QString& programName )
 {
     QString p = K3b::prepareDir( dir ) + programName;
-#ifdef Q_OS_WIN32
+#ifdef Q_OS_WIN
     p += ".exe";
 #endif
     return p;
@@ -240,11 +343,9 @@ bool K3b::SimpleExternalProgram::scan( const QString& p )
     QString path = getProgramPath( p );
 
     if ( QFile::exists( path ) ) {
-        K3b::ExternalBin* bin = new ExternalBin( this );
-        bin->path = path;
+        K3b::ExternalBin* bin = new ExternalBin( *this, path );
 
-        if ( !scanVersion( *bin ) ||
-             !scanFeatures( *bin ) ) {
+        if ( ( !scanVersion( *bin ) || !scanFeatures( *bin ) ) && bin->needGroup().isEmpty() )  {
             delete bin;
             return false;
         }
@@ -263,14 +364,29 @@ bool K3b::SimpleExternalProgram::scanVersion( ExternalBin& bin ) const
     // probe version
     KProcess vp;
     vp.setOutputChannelMode( KProcess::MergedChannels );
-    vp << bin.path << "--version";
-    if( vp.execute( EXECUTE_TIMEOUT ) < 0 )
+    vp << bin.path() << "--version";
+    if( vp.execute( EXECUTE_TIMEOUT ) < 0 ) {
+        if( vp.error() == 0 ) {
+            qDebug() << "Insufficient permissions for" << bin.path();
+            // try to get real group or set fictive group to make
+            // K3b::SystemProblemDialog::checkSystem work
+            struct stat st;
+            if( !::stat( QFile::encodeName(bin.path()), &st ) ) {
+                QString group( getgrgid( st.st_gid )->gr_name );
+                qDebug() << "Should be member of \"" << group << "\"";
+                bin.setNeedGroup( group.isEmpty() ? "N/A" : group );
+            } else
+                bin.setNeedGroup( "N/A" );
+        }
         return false;
+    }
 
+    // set empty group to make K3b::SystemProblemDialog::checkSystem work
+    bin.setNeedGroup( "" );
     QString s = QString::fromLocal8Bit( vp.readAll() );
-    bin.version = parseVersion( s, bin );
-    bin.copyright = parseCopyright( s, bin );
-    return bin.version.isValid();
+    bin.setVersion( parseVersion( s, bin ) );
+    bin.setCopyright( parseCopyright( s, bin ) );
+    return bin.version().isValid();
 }
 
 
@@ -279,7 +395,7 @@ bool K3b::SimpleExternalProgram::scanFeatures( ExternalBin& bin ) const
 #ifndef Q_OS_WIN32
     // check if we run as root
     struct stat s;
-    if( !::stat( QFile::encodeName(bin.path), &s ) ) {
+    if( !::stat( QFile::encodeName(bin.path()), &s ) ) {
         if( (s.st_mode & S_ISUID) && s.st_uid == 0 )
             bin.addFeature( "suidroot" );
     }
@@ -288,7 +404,7 @@ bool K3b::SimpleExternalProgram::scanFeatures( ExternalBin& bin ) const
     // probe features
     KProcess fp;
     fp.setOutputChannelMode( KProcess::MergedChannels );
-    fp << bin.path << "--help";
+    fp << bin.path() << "--help";
     if( fp.execute( EXECUTE_TIMEOUT ) < 0 )
         return false;
 
@@ -359,8 +475,24 @@ QString K3b::SimpleExternalProgram::versionIdentifier( const ExternalBin& /*bin*
 // ///////////////////////////////////////////////////////////
 
 
+class K3b::ExternalBinManager::Private
+{
+public:
+    QMap<QString, ExternalProgram*> programs;
+    QStringList searchPath;
+
+    static QString noPath;  // used for binPath() to return const string
+
+    QString gatheredOutput;
+};
+
+
+QString K3b::ExternalBinManager::Private::noPath = "";
+
+
 K3b::ExternalBinManager::ExternalBinManager( QObject* parent )
-    : QObject( parent )
+    : QObject( parent ),
+      d( new Private )
 {
 }
 
@@ -368,6 +500,7 @@ K3b::ExternalBinManager::ExternalBinManager( QObject* parent )
 K3b::ExternalBinManager::~ExternalBinManager()
 {
     clear();
+    delete d;
 }
 
 
@@ -381,7 +514,7 @@ bool K3b::ExternalBinManager::readConfig( const KConfigGroup& grp )
 
     search();
 
-    Q_FOREACH( K3b::ExternalProgram* p, m_programs ) {
+    Q_FOREACH( K3b::ExternalProgram* p, d->programs ) {
         if( grp.hasKey( p->name() + " default" ) ) {
             p->setDefault( grp.readEntry( p->name() + " default", QString() ) );
         }
@@ -394,7 +527,7 @@ bool K3b::ExternalBinManager::readConfig( const KConfigGroup& grp )
         // now search for a newer version and use it (because it was installed after the last
         // K3b run and most users would probably expect K3b to use a newly installed version)
         const K3b::ExternalBin* newestBin = p->mostRecentBin();
-        if( newestBin && newestBin->version > lastMax )
+        if( newestBin && newestBin->version() > lastMax )
             p->setDefault( newestBin );
     }
 
@@ -404,17 +537,17 @@ bool K3b::ExternalBinManager::readConfig( const KConfigGroup& grp )
 
 bool K3b::ExternalBinManager::saveConfig( KConfigGroup grp )
 {
-    grp.writePathEntry( "search path", m_searchPath );
+    grp.writePathEntry( "search path", d->searchPath );
 
-    Q_FOREACH( K3b::ExternalProgram* p, m_programs ) {
+    Q_FOREACH( K3b::ExternalProgram* p, d->programs ) {
         if( p->defaultBin() )
-            grp.writeEntry( p->name() + " default", p->defaultBin()->path );
+            grp.writeEntry( p->name() + " default", p->defaultBin()->path() );
 
         grp.writeEntry( p->name() + " user parameters", p->userParameters() );
 
         const K3b::ExternalBin* newestBin = p->mostRecentBin();
         if( newestBin )
-            grp.writeEntry( p->name() + " last seen newest version", newestBin->version.toString() );
+            grp.writeEntry( p->name() + " last seen newest version", newestBin->version().toString() );
     }
 
     return true;
@@ -423,70 +556,88 @@ bool K3b::ExternalBinManager::saveConfig( KConfigGroup grp )
 
 bool K3b::ExternalBinManager::foundBin( const QString& name )
 {
-    if( m_programs.constFind( name ) == m_programs.constEnd() )
+    if( d->programs.constFind( name ) == d->programs.constEnd() )
         return false;
     else
-        return (m_programs[name]->defaultBin() != 0);
+        return (d->programs[name]->defaultBin() != 0);
 }
 
 
 QString K3b::ExternalBinManager::binPath( const QString& name )
 {
-    if( m_programs.constFind( name ) == m_programs.constEnd() )
-        return m_noPath;
+    if( d->programs.constFind( name ) == d->programs.constEnd() )
+        return Private::noPath;
 
-    if( m_programs[name]->defaultBin() != 0 )
-        return m_programs[name]->defaultBin()->path;
+    if( d->programs[name]->defaultBin() != 0 )
+        return d->programs[name]->defaultBin()->path();
     else
-        return m_noPath;
+        return Private::noPath;
 }
 
 
 const K3b::ExternalBin* K3b::ExternalBinManager::binObject( const QString& name )
 {
-    if( m_programs.constFind( name ) == m_programs.constEnd() )
+    if( d->programs.constFind( name ) == d->programs.constEnd() )
         return 0;
 
-    return m_programs[name]->defaultBin();
+    return d->programs[name]->defaultBin();
+}
+
+
+QString K3b::ExternalBinManager::binNeedGroup( const QString& name )
+{
+    if( d->programs.constFind( name ) == d->programs.constEnd() )
+        return QString();
+
+    if( d->programs[name]->defaultBin() != 0 )
+        return d->programs[name]->defaultBin()->needGroup();
+
+    return QString();
 }
 
 
 void K3b::ExternalBinManager::addProgram( K3b::ExternalProgram* p )
 {
-    m_programs.insert( p->name(), p );
+    d->programs.insert( p->name(), p );
 }
 
 
 void K3b::ExternalBinManager::clear()
 {
-    qDeleteAll( m_programs );
-    m_programs.clear();
+    qDeleteAll( d->programs );
+    d->programs.clear();
 }
 
 
 void K3b::ExternalBinManager::search()
 {
-    if( m_searchPath.isEmpty() )
+    if( d->searchPath.isEmpty() )
         loadDefaultSearchPath();
 
-    Q_FOREACH( K3b::ExternalProgram* program, m_programs ) {
+    Q_FOREACH( K3b::ExternalProgram* program, d->programs ) {
         program->clear();
     }
 
     // do not search one path twice
     QStringList paths;
-    const QStringList possiblePaths = m_searchPath + KStandardDirs::systemPaths();
+#ifdef Q_OS_WIN
+    const QChar pathSep = QChar::fromLatin1( ';' );
+#else
+    const QChar pathSep = QChar::fromLatin1( ':' );
+#endif
+    const QStringList possiblePaths = QString::fromLatin1( qgetenv( "PATH" ) ).split( pathSep, QString::SkipEmptyParts )
+                                      + d->searchPath;
     foreach( QString p, possiblePaths ) {
         if (p.length() == 0)
             continue;
         if( p[p.length()-1] == '/' )
             p.truncate( p.length()-1 );
-        if( !paths.contains( p ) && !paths.contains( p + "/" ) )
+        if( !paths.contains( p ) && !paths.contains( p + '/' ) )
             paths.append(p);
     }
 
     Q_FOREACH( const QString& path, paths ) {
-        Q_FOREACH( K3b::ExternalProgram* program, m_programs ) {
+        Q_FOREACH( K3b::ExternalProgram* program, d->programs ) {
             program->scan( path );
         }
     }
@@ -495,10 +646,16 @@ void K3b::ExternalBinManager::search()
 
 K3b::ExternalProgram* K3b::ExternalBinManager::program( const QString& name ) const
 {
-    if( m_programs.find( name ) == m_programs.constEnd() )
+    if( d->programs.constFind( name ) == d->programs.constEnd() )
         return 0;
     else
-        return m_programs[name];
+        return d->programs[name];
+}
+
+
+QMap<QString, K3b::ExternalProgram*> K3b::ExternalBinManager::programs() const
+{
+    return d->programs;
 }
 
 
@@ -510,23 +667,28 @@ void K3b::ExternalBinManager::loadDefaultSearchPath()
                                                 "/usr/local/bin/",
                                                 "/usr/sbin/",
                                                 "/usr/local/sbin/",
-                                                "/opt/schily/bin/",
                                                 "/sbin",
 #endif
                                                 0 };
 
-    m_searchPath.clear();
+    d->searchPath.clear();
     for( int i = 0; defaultSearchPaths[i]; ++i ) {
-        m_searchPath.append( defaultSearchPaths[i] );
+        d->searchPath.append( defaultSearchPaths[i] );
     }
 }
 
 
+QStringList K3b::ExternalBinManager::searchPath() const
+{
+    return d->searchPath;
+}
+
+
 void K3b::ExternalBinManager::setSearchPath( const QStringList& list )
 {
-    m_searchPath.clear();
+    d->searchPath.clear();
     for( QStringList::const_iterator it = list.constBegin(); it != list.constEnd(); ++it ) {
-        m_searchPath.append( QDir::fromNativeSeparators( *it ) );
+        d->searchPath.append( QDir::fromNativeSeparators( *it ) );
     }
 }
 
@@ -534,12 +696,11 @@ void K3b::ExternalBinManager::setSearchPath( const QStringList& list )
 void K3b::ExternalBinManager::addSearchPath( const QString& path )
 {
     QString aPath = QDir::fromNativeSeparators( path );
-    if( !m_searchPath.contains( aPath ) )
-        m_searchPath.append( aPath );
+    if( !d->searchPath.contains( aPath ) )
+        d->searchPath.append( aPath );
 }
 
 
-
 const K3b::ExternalBin* K3b::ExternalBinManager::mostRecentBinObject( const QString& name )
 {
     if( K3b::ExternalProgram* p = program( name ) )
@@ -548,5 +709,5 @@ const K3b::ExternalBin* K3b::ExternalBinManager::mostRecentBinObject( const QStr
         return 0;
 }
 
-#include "k3bexternalbinmanager.moc"
+
 
