@@ -1,6 +1,7 @@
 /*
  *
  * Copyright (C) 2003-2010 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 2011 Michal Malek <michalm@jabster.pl>
  *
  * This file is part of the K3b project.
  * Copyright (C) 1998-2010 Sebastian Trueg <trueg@k3b.org>
@@ -30,27 +31,26 @@
 #include "k3binffilewriter.h"
 #include "k3bglobalsettings.h"
 #include "k3bcddb.h"
+#include "k3b_i18n.h"
 
-#include <kconfig.h>
-#include <kstandarddirs.h>
-#include <klocale.h>
-#include <kdebug.h>
-#include <ktemporaryfile.h>
-#include <kio/netaccess.h>
-#include <kio/job.h>
-#include <kio/global.h>
+#include <KConfigCore/KConfig>
+#include <KIOCore/KIO/Global>
+#include <KIOCore/KIO/DeleteJob>
+#include <KIOCore/KIO/Job>
 
-#include <qtimer.h>
-#include <qstringlist.h>
-#include <qfile.h>
-#include <qregexp.h>
-#include <qfileinfo.h>
-#include <qdir.h>
-#include <qapplication.h>
-#include <qvector.h>
+#include <QtCore/QDebug>
+#include <QtCore/QDir>
+#include <QtCore/QFile>
+#include <QtCore/QFileInfo>
+#include <QtCore/QRegExp>
+#include <QtCore/QStringList>
+#include <QtCore/QTemporaryFile>
+#include <QtCore/QTimer>
+#include <QtCore/QVector>
+#include <QtWidgets/QApplication>
 
-#include <libkcddb/client.h>
-#include <libkcddb/cdinfo.h>
+#include <KCddb/Client>
+#include <KCddb/Cdinfo>
 
 
 
@@ -247,11 +247,11 @@ void K3b::CdCopyJob::slotDiskInfoReady( K3b::Device::DeviceHandler* dh )
                 if( m_readerDevice->read10( buffer, 2048, (*it).lastSector().lba(), 1 ) ||
                     m_readerDevice->read10( buffer, 2048, (*it).lastSector().lba(), 1 ) ) {
                     d->dataSessionProbablyTAORecorded.append(false);
-                    kDebug() << "(K3b::CdCopyJob) track " << i << " probably DAO recorded.";
+                    qDebug() << "(K3b::CdCopyJob) track " << i << " probably DAO recorded.";
                 }
                 else {
                     d->dataSessionProbablyTAORecorded.append(true);
-                    kDebug() << "(K3b::CdCopyJob) track " << i << " probably TAO recorded.";
+                    qDebug() << "(K3b::CdCopyJob) track " << i << " probably TAO recorded.";
                 }
             }
 
@@ -368,7 +368,7 @@ void K3b::CdCopyJob::slotDiskInfoReady( K3b::Device::DeviceHandler* dh )
 
 void K3b::CdCopyJob::searchCdText()
 {
-    emit newSubTask( i18n("Searching CD-TEXT") );
+    emit newSubTask( i18n("Searching CD-Text") );
 
     connect( K3b::Device::sendCommand( K3b::Device::DeviceHandler::CommandCdTextRaw, m_readerDevice ),
              SIGNAL(finished(K3b::Device::DeviceHandler*)),
@@ -382,17 +382,17 @@ void K3b::CdCopyJob::slotCdTextReady( K3b::Device::DeviceHandler* dh )
     if( dh->success() ) {
         if( K3b::Device::CdText::checkCrc( dh->cdTextRaw() ) ) {
             K3b::Device::CdText cdt( dh->cdTextRaw() );
-            emit infoMessage( i18n("Found CD-TEXT (%1 - %2).",cdt.performer(),cdt.title()), MessageSuccess );
+            emit infoMessage( i18n("Found CD-Text (%1 - %2).",cdt.performer(),cdt.title()), MessageSuccess );
             d->haveCdText = true;
             d->cdTextRaw = dh->cdTextRaw();
         }
         else {
-            emit infoMessage( i18n("Found corrupted CD-TEXT. Ignoring it."), MessageWarning );
+            emit infoMessage( i18n("Found corrupted CD-Text. Ignoring it."), MessageWarning );
             d->haveCdText = false;
         }
     }
     else {
-        emit infoMessage( i18n("No CD-TEXT found."), MessageInfo );
+        emit infoMessage( i18n("No CD-Text found."), MessageInfo );
 
         d->haveCdText = false;
     }
@@ -403,18 +403,18 @@ void K3b::CdCopyJob::slotCdTextReady( K3b::Device::DeviceHandler* dh )
 
 void K3b::CdCopyJob::queryCddb()
 {
-    emit newSubTask( i18n("Querying Cddb") );
+    emit newSubTask( i18n("Querying CDDB") );
 
     d->haveCddb = false;
 
     if( !d->cddb ) {
         d->cddb = new KCDDB::Client();
         d->cddb->setBlockingMode( false );
-        connect( d->cddb, SIGNAL( finished( KCDDB::Result ) ),
-                 this, SLOT( slotCddbQueryFinished( KCDDB::Result ) ) );
+        connect( d->cddb, SIGNAL(finished(KCDDB::Result)),
+                 this, SLOT(slotCddbQueryFinished(KCDDB::Result)) );
     }
 
-    d->cddb->config().readConfig();
+    d->cddb->config().load();
     d->cddb->lookup( K3b::CDDB::createTrackOffsetList( d->toc ) );
 }
 
@@ -424,7 +424,7 @@ void K3b::CdCopyJob::slotCddbQueryFinished( KCDDB::Result result )
     if( result == KCDDB::Success ) {
         d->cddbInfo = d->cddb->lookupResponse().first();
         d->haveCddb = true;
-        emit infoMessage( i18n("Found Cddb entry (%1 - %2).",
+        emit infoMessage( i18n("Found CDDB entry (%1 - %2).",
                                d->cddbInfo.get( KCDDB::Artist ).toString(),
                                d->cddbInfo.get( KCDDB::Title ).toString() ),
                           MessageSuccess );
@@ -447,10 +447,10 @@ void K3b::CdCopyJob::slotCddbQueryFinished( KCDDB::Result result )
         }
     }
     else if( result == KCDDB::NoRecordFound ) {
-        emit infoMessage( i18n("No Cddb entry found."), MessageWarning );
+        emit infoMessage( i18n("No CDDB entry found."), MessageWarning );
     }
     else {
-        emit infoMessage( i18n("Cddb error (%1).",
+        emit infoMessage( i18n("CDDB error (%1).",
                                KCDDB::resultToString( result ) ),
                           MessageError );
     }
@@ -466,15 +466,15 @@ void K3b::CdCopyJob::startCopy()
 
     if ( d->haveCdText && d->haveCddb ) {
         K3b::Device::CdText cdt( d->cdTextRaw );
-        if ( !questionYesNo( i18n( "Found CD-TEXT (%1 - %2) and Cddb (%3 - %4) entries. "
-                                   "Which one should be used to generate the CD-TEXT on the new CD?",
+        if ( !questionYesNo( i18n( "Found CD-Text (%1 - %2) and CDDB (%3 - %4) entries. "
+                                   "Which one should be used to generate the CD-Text on the new CD?",
                                    cdt.performer(),
                                    cdt.title(),
                                    d->cddbInfo.get( KCDDB::Artist ).toString(),
                                    d->cddbInfo.get( KCDDB::Title ).toString() ),
-                             i18n( "CD-TEXT" ),
-                             KGuiItem( i18n( "Use CD-TEXT data" ) ),
-                             KGuiItem( i18n( "Use Cddb entry" ) ) ) ) {
+                             i18n( "CD-Text" ),
+                             KGuiItem( i18n( "Use CD-Text data" ) ),
+                             KGuiItem( i18n( "Use CDDB entry" ) ) ) ) {
             d->haveCdText = false;
         }
     }
@@ -515,7 +515,7 @@ void K3b::CdCopyJob::cancel()
 
 bool K3b::CdCopyJob::prepareImageFiles()
 {
-    kDebug() << "(K3b::CdCopyJob) prepareImageFiles()";
+    qDebug() << "(K3b::CdCopyJob) prepareImageFiles()";
 
     d->imageNames.clear();
     d->infNames.clear();
@@ -548,7 +548,7 @@ bool K3b::CdCopyJob::prepareImageFiles()
         if( !tempDirReady ) {
             QDir dir( m_tempPath );
             m_tempPath = K3b::findUniqueFilePrefix( "k3bCdCopy", m_tempPath );
-            kDebug() << "(K3b::CdCopyJob) creating temp dir: " << m_tempPath;
+            qDebug() << "(K3b::CdCopyJob) creating temp dir: " << m_tempPath;
             if( !dir.mkdir( m_tempPath ) ) {
                 emit infoMessage( i18n("Unable to create temporary folder '%1'.",m_tempPath), MessageError );
                 return false;
@@ -571,9 +571,9 @@ bool K3b::CdCopyJob::prepareImageFiles()
             ++i;
         }
 
-        kDebug() << "(K3b::CdCopyJob) created image filenames:";
+        qDebug() << "(K3b::CdCopyJob) created image filenames:";
         for( int i = 0; i < d->imageNames.count(); ++i )
-            kDebug() << "(K3b::CdCopyJob) " << d->imageNames[i];
+            qDebug() << "(K3b::CdCopyJob) " << d->imageNames[i];
 
         return true;
     }
@@ -620,8 +620,8 @@ void K3b::CdCopyJob::readNextSession()
     if( d->currentReadSession == 1 && d->toc[0].type() == K3b::Device::Track::TYPE_AUDIO ) {
         if( !d->audioSessionReader ) {
             d->audioSessionReader = new K3b::AudioSessionReadingJob( this, this );
-            connect( d->audioSessionReader, SIGNAL(nextTrack(int, int)),
-                     this, SLOT(slotReadingNextTrack(int, int)) );
+            connect( d->audioSessionReader, SIGNAL(nextTrack(int,int)),
+                     this, SLOT(slotReadingNextTrack(int,int)) );
             connectSubJob( d->audioSessionReader,
                            SLOT(slotSessionReaderFinished(bool)),
                            K3b::Job::DEFAULT_SIGNAL_CONNECTION,
@@ -647,11 +647,11 @@ void K3b::CdCopyJob::readNextSession()
         if( !d->dataTrackReader ) {
             d->dataTrackReader = new K3b::DataTrackReader( this, this );
             connect( d->dataTrackReader, SIGNAL(percent(int)), this, SLOT(slotReaderProgress(int)) );
-            connect( d->dataTrackReader, SIGNAL(processedSize(int, int)), this, SLOT(slotReaderProcessedSize(int, int)) );
+            connect( d->dataTrackReader, SIGNAL(processedSize(int,int)), this, SLOT(slotReaderProcessedSize(int,int)) );
             connect( d->dataTrackReader, SIGNAL(finished(bool)), this, SLOT(slotSessionReaderFinished(bool)) );
-            connect( d->dataTrackReader, SIGNAL(infoMessage(const QString&, int)), this, SIGNAL(infoMessage(const QString&, int)) );
-            connect( d->dataTrackReader, SIGNAL(debuggingOutput(const QString&, const QString&)),
-                     this, SIGNAL(debuggingOutput(const QString&, const QString&)) );
+            connect( d->dataTrackReader, SIGNAL(infoMessage(QString,int)), this, SIGNAL(infoMessage(QString,int)) );
+            connect( d->dataTrackReader, SIGNAL(debuggingOutput(QString,QString)),
+                     this, SIGNAL(debuggingOutput(QString,QString)) );
         }
 
         d->dataTrackReader->setDevice( m_readerDevice );
@@ -732,20 +732,20 @@ bool K3b::CdCopyJob::writeNextSession()
 
     if( !d->cdrecordWriter ) {
         d->cdrecordWriter = new K3b::CdrecordWriter( m_writerDevice, this, this );
-        connect( d->cdrecordWriter, SIGNAL(infoMessage(const QString&, int)), this, SIGNAL(infoMessage(const QString&, int)) );
+        connect( d->cdrecordWriter, SIGNAL(infoMessage(QString,int)), this, SIGNAL(infoMessage(QString,int)) );
         connect( d->cdrecordWriter, SIGNAL(percent(int)), this, SLOT(slotWriterProgress(int)) );
-        connect( d->cdrecordWriter, SIGNAL(processedSize(int, int)), this, SIGNAL(processedSize(int, int)) );
+        connect( d->cdrecordWriter, SIGNAL(processedSize(int,int)), this, SIGNAL(processedSize(int,int)) );
         connect( d->cdrecordWriter, SIGNAL(subPercent(int)), this, SIGNAL(subPercent(int)) );
-        connect( d->cdrecordWriter, SIGNAL(processedSubSize(int, int)), this, SIGNAL(processedSubSize(int, int)) );
-        connect( d->cdrecordWriter, SIGNAL(nextTrack(int, int)), this, SLOT(slotWritingNextTrack(int, int)) );
+        connect( d->cdrecordWriter, SIGNAL(processedSubSize(int,int)), this, SIGNAL(processedSubSize(int,int)) );
+        connect( d->cdrecordWriter, SIGNAL(nextTrack(int,int)), this, SLOT(slotWritingNextTrack(int,int)) );
         connect( d->cdrecordWriter, SIGNAL(buffer(int)), this, SIGNAL(bufferStatus(int)) );
         connect( d->cdrecordWriter, SIGNAL(deviceBuffer(int)), this, SIGNAL(deviceBuffer(int)) );
-        connect( d->cdrecordWriter, SIGNAL(writeSpeed(int, K3b::Device::SpeedMultiplicator)), this, SIGNAL(writeSpeed(int, K3b::Device::SpeedMultiplicator)) );
+        connect( d->cdrecordWriter, SIGNAL(writeSpeed(int,K3b::Device::SpeedMultiplicator)), this, SIGNAL(writeSpeed(int,K3b::Device::SpeedMultiplicator)) );
         connect( d->cdrecordWriter, SIGNAL(finished(bool)), this, SLOT(slotWriterFinished(bool)) );
-        //    connect( d->cdrecordWriter, SIGNAL(newTask(const QString&)), this, SIGNAL(newTask(const QString&)) );
-        connect( d->cdrecordWriter, SIGNAL(newSubTask(const QString&)), this, SIGNAL(newSubTask(const QString&)) );
-        connect( d->cdrecordWriter, SIGNAL(debuggingOutput(const QString&, const QString&)),
-                 this, SIGNAL(debuggingOutput(const QString&, const QString&)) );
+        //    connect( d->cdrecordWriter, SIGNAL(newTask(QString)), this, SIGNAL(newTask(QString)) );
+        connect( d->cdrecordWriter, SIGNAL(newSubTask(QString)), this, SIGNAL(newSubTask(QString)) );
+        connect( d->cdrecordWriter, SIGNAL(debuggingOutput(QString,QString)),
+                 this, SIGNAL(debuggingOutput(QString,QString)) );
     }
 
     d->cdrecordWriter->setBurnDevice( m_writerDevice );
@@ -797,8 +797,7 @@ bool K3b::CdCopyJob::writeNextSession()
                     // the same way we delete them when writing with images
                     // It is important that the files have the ending inf because
                     // cdrecord only checks this
-                    KTemporaryFile tmp;
-                    tmp.setSuffix( ".inf" );
+                    QTemporaryFile tmp( "XXXXXX.inf" );
                     tmp.setAutoRemove( false );
                     tmp.open();
                     d->infNames.append( tmp.fileName() );
@@ -1098,7 +1097,7 @@ void K3b::CdCopyJob::slotWriterFinished( bool success )
 void K3b::CdCopyJob::slotMediaReloadedForNextSession( K3b::Device::DeviceHandler* dh )
 {
     if( !dh->success() )
-        blockingInformation( i18n("Please reload the medium and press 'ok'"),
+        blockingInformation( i18n("Please reload the medium and press 'OK'"),
                              i18n("Failed to reload the medium") );
 
     if( !writeNextSession() ) {
@@ -1125,7 +1124,7 @@ void K3b::CdCopyJob::cleanup()
 
         // remove the tempdir created in prepareImageFiles()
         if( d->deleteTempDir ) {
-            KIO::NetAccess::del( m_tempPath, 0 );
+            KIO::del( QUrl::fromLocalFile( m_tempPath ), KIO::HideProgressInfo )->exec();
             d->deleteTempDir = false;
         }
     }
@@ -1233,6 +1232,24 @@ QString K3b::CdCopyJob::jobDetails() const
 }
 
 
+QString K3b::CdCopyJob::jobSource() const
+{
+    if( Device::Device* device = reader() )
+        return device->vendor() + ' ' + device->description();
+    else
+        return QString();
+}
+
+
+QString K3b::CdCopyJob::jobTarget() const
+{
+    if( Device::Device* device = writer() )
+        return device->vendor() + ' ' + device->description();
+    else
+        return m_tempPath;
+}
+
+
 void K3b::CdCopyJob::finishJob( bool c, bool e )
 {
     if( d->running ) {
@@ -1251,4 +1268,4 @@ void K3b::CdCopyJob::finishJob( bool c, bool e )
     }
 }
 
-#include "k3bcdcopyjob.moc"
+
