@@ -1,6 +1,7 @@
 /*
  *
  * Copyright (C) 2003-2010 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 2011 Michal Malek <michalm@jabster.pl>
  *
  * This file is part of the K3b project.
  * Copyright (C) 1998-2010 Sebastian Trueg <trueg@k3b.org>
@@ -32,14 +33,13 @@
 #include "k3bchecksumpipe.h"
 #include "k3bverificationjob.h"
 #include "k3bglobalsettings.h"
+#include "k3b_i18n.h"
 
-#include <kdebug.h>
-#include <klocale.h>
-#include <kio/global.h>
+#include <KIOCore/KIO/Global>
 
-#include <qfile.h>
-#include <qfileinfo.h>
-#include <qapplication.h>
+#include <QtCore/QDebug>
+#include <QtCore/QFile>
+#include <QtCore/QFileInfo>
 
 
 class K3b::DvdCopyJob::Private
@@ -122,10 +122,10 @@ void K3b::DvdCopyJob::start()
     emit newTask( i18n("Checking Source Medium") );
 
     if( m_onTheFly &&
-        k3bcore->externalBinManager()->binObject( "growisofs" )->version < K3b::Version( 5, 12 ) ) {
+        k3bcore->externalBinManager()->binObject( "growisofs" )->version() < K3b::Version( 5, 12 ) ) {
         m_onTheFly = false;
         emit infoMessage( i18n("K3b does not support writing on-the-fly with growisofs %1.",
-                          k3bcore->externalBinManager()->binObject( "growisofs" )->version), MessageError );
+                          k3bcore->externalBinManager()->binObject( "growisofs" )->version()), MessageError );
         emit infoMessage( i18n("Disabling on-the-fly writing."), MessageInfo );
     }
 
@@ -190,17 +190,17 @@ void K3b::DvdCopyJob::slotDiskInfoReady( K3b::Device::DeviceHandler* dh )
             emit infoMessage( i18n("Found encrypted DVD."), MessageWarning );
             // check for libdvdcss
             bool haveLibdvdcss = false;
-            kDebug() << "(K3b::DvdCopyJob) trying to open libdvdcss.";
+            qDebug() << "(K3b::DvdCopyJob) trying to open libdvdcss.";
             if( K3b::LibDvdCss* libcss = K3b::LibDvdCss::create() ) {
-                kDebug() << "(K3b::DvdCopyJob) succeeded.";
-                kDebug() << "(K3b::DvdCopyJob) dvdcss_open(" << m_readerDevice->blockDeviceName() << ") = "
+                qDebug() << "(K3b::DvdCopyJob) succeeded.";
+                qDebug() << "(K3b::DvdCopyJob) dvdcss_open(" << m_readerDevice->blockDeviceName() << ") = "
                           << libcss->open(m_readerDevice) << endl;
                 haveLibdvdcss = true;
 
                 delete libcss;
             }
             else
-                kDebug() << "(K3b::DvdCopyJob) failed.";
+                qDebug() << "(K3b::DvdCopyJob) failed.";
 
             if( !haveLibdvdcss ) {
                 emit infoMessage( i18n("Cannot copy encrypted DVDs."), MessageError );
@@ -286,7 +286,7 @@ void K3b::DvdCopyJob::slotDiskInfoReady( K3b::Device::DeviceHandler* dh )
         case K3b::Device::MEDIA_DVD_RW_OVWR:
         case K3b::Device::MEDIA_BD_RE:
         {
-            emit infoMessage( i18n("K3b relies on the size saved in the ISO9660 header."), MessageWarning );
+            emit infoMessage( i18n("K3b relies on the size saved in the ISO 9660 header."), MessageWarning );
             emit infoMessage( i18n("This might result in a corrupt copy if the source was mastered with buggy software."), MessageWarning );
 
             K3b::Iso9660 isoF( m_readerDevice, 0 );
@@ -294,7 +294,7 @@ void K3b::DvdCopyJob::slotDiskInfoReady( K3b::Device::DeviceHandler* dh )
                 d->lastSector = ((long long)isoF.primaryDescriptor().logicalBlockSize*isoF.primaryDescriptor().volumeSpaceSize)/2048LL - 1;
             }
             else {
-                emit infoMessage( i18n("Unable to determine the ISO9660 filesystem size."), MessageError );
+                emit infoMessage( i18n("Unable to determine the ISO 9660 filesystem size."), MessageError );
                 jobFinished(false);
                 d->running = false;
                 return;
@@ -424,7 +424,7 @@ void K3b::DvdCopyJob::cancel()
         d->imageFile.close();
     }
     else {
-        kDebug() << "(K3b::DvdCopyJob) not running.";
+        qDebug() << "(K3b::DvdCopyJob) not running.";
     }
 }
 
@@ -434,12 +434,12 @@ void K3b::DvdCopyJob::prepareReader()
     if( !d->dataTrackReader ) {
         d->dataTrackReader = new K3b::DataTrackReader( this );
         connect( d->dataTrackReader, SIGNAL(percent(int)), this, SLOT(slotReaderProgress(int)) );
-        connect( d->dataTrackReader, SIGNAL(processedSize(int, int)), this, SLOT(slotReaderProcessedSize(int, int)) );
+        connect( d->dataTrackReader, SIGNAL(processedSize(int,int)), this, SLOT(slotReaderProcessedSize(int,int)) );
         connect( d->dataTrackReader, SIGNAL(finished(bool)), this, SLOT(slotReaderFinished(bool)) );
-        connect( d->dataTrackReader, SIGNAL(infoMessage(const QString&, int)), this, SIGNAL(infoMessage(const QString&, int)) );
-        connect( d->dataTrackReader, SIGNAL(newTask(const QString&)), this, SIGNAL(newSubTask(const QString&)) );
-        connect( d->dataTrackReader, SIGNAL(debuggingOutput(const QString&, const QString&)),
-                 this, SIGNAL(debuggingOutput(const QString&, const QString&)) );
+        connect( d->dataTrackReader, SIGNAL(infoMessage(QString,int)), this, SIGNAL(infoMessage(QString,int)) );
+        connect( d->dataTrackReader, SIGNAL(newTask(QString)), this, SIGNAL(newSubTask(QString)) );
+        connect( d->dataTrackReader, SIGNAL(debuggingOutput(QString,QString)),
+                 this, SIGNAL(debuggingOutput(QString,QString)) );
     }
 
     d->dataTrackReader->setDevice( m_readerDevice );
@@ -507,18 +507,18 @@ void K3b::DvdCopyJob::prepareWriter()
     }
 
 
-    connect( d->writerJob, SIGNAL(infoMessage(const QString&, int)), this, SIGNAL(infoMessage(const QString&, int)) );
+    connect( d->writerJob, SIGNAL(infoMessage(QString,int)), this, SIGNAL(infoMessage(QString,int)) );
     connect( d->writerJob, SIGNAL(percent(int)), this, SLOT(slotWriterProgress(int)) );
-    connect( d->writerJob, SIGNAL(processedSize(int, int)), this, SIGNAL(processedSize(int, int)) );
-    connect( d->writerJob, SIGNAL(processedSubSize(int, int)), this, SIGNAL(processedSubSize(int, int)) );
+    connect( d->writerJob, SIGNAL(processedSize(int,int)), this, SIGNAL(processedSize(int,int)) );
+    connect( d->writerJob, SIGNAL(processedSubSize(int,int)), this, SIGNAL(processedSubSize(int,int)) );
     connect( d->writerJob, SIGNAL(buffer(int)), this, SIGNAL(bufferStatus(int)) );
     connect( d->writerJob, SIGNAL(deviceBuffer(int)), this, SIGNAL(deviceBuffer(int)) );
-    connect( d->writerJob, SIGNAL(writeSpeed(int, K3b::Device::SpeedMultiplicator)), this, SIGNAL(writeSpeed(int, K3b::Device::SpeedMultiplicator)) );
+    connect( d->writerJob, SIGNAL(writeSpeed(int,K3b::Device::SpeedMultiplicator)), this, SIGNAL(writeSpeed(int,K3b::Device::SpeedMultiplicator)) );
     connect( d->writerJob, SIGNAL(finished(bool)), this, SLOT(slotWriterFinished(bool)) );
-    //  connect( d->writerJob, SIGNAL(newTask(const QString&)), this, SIGNAL(newTask(const QString&)) );
-    connect( d->writerJob, SIGNAL(newSubTask(const QString&)), this, SIGNAL(newSubTask(const QString&)) );
-    connect( d->writerJob, SIGNAL(debuggingOutput(const QString&, const QString&)),
-             this, SIGNAL(debuggingOutput(const QString&, const QString&)) );
+    //  connect( d->writerJob, SIGNAL(newTask(QString)), this, SIGNAL(newTask(QString)) );
+    connect( d->writerJob, SIGNAL(newSubTask(QString)), this, SIGNAL(newSubTask(QString)) );
+    connect( d->writerJob, SIGNAL(debuggingOutput(QString,QString)),
+             this, SIGNAL(debuggingOutput(QString,QString)) );
 }
 
 
@@ -587,7 +587,7 @@ void K3b::DvdCopyJob::slotReaderFinished( bool success )
                 // eject the media (we do this blocking to know if it worked
                 // because if it did not it might happen that k3b overwrites a CD-RW
                 // source)
-                kDebug() << "Ejecting read medium" << m_readerDevice->blockDeviceName();
+                qDebug() << "Ejecting read medium" << m_readerDevice->blockDeviceName();
                 if( !K3b::eject( m_readerDevice ) ) {
                     blockingInformation( i18n("K3b was unable to eject the source medium. Please do so manually.") );
                 }
@@ -655,18 +655,18 @@ void K3b::DvdCopyJob::slotWriterFinished( bool success )
         if( d->verifyData && !m_simulate ) {
             if( !d->verificationJob ) {
                 d->verificationJob = new K3b::VerificationJob( this, this );
-                connect( d->verificationJob, SIGNAL(infoMessage(const QString&, int)),
-                         this, SIGNAL(infoMessage(const QString&, int)) );
-                connect( d->verificationJob, SIGNAL(newTask(const QString&)),
-                         this, SIGNAL(newSubTask(const QString&)) );
+                connect( d->verificationJob, SIGNAL(infoMessage(QString,int)),
+                         this, SIGNAL(infoMessage(QString,int)) );
+                connect( d->verificationJob, SIGNAL(newTask(QString)),
+                         this, SIGNAL(newSubTask(QString)) );
                 connect( d->verificationJob, SIGNAL(percent(int)),
                          this, SLOT(slotVerificationProgress(int)) );
                 connect( d->verificationJob, SIGNAL(percent(int)),
                          this, SIGNAL(subPercent(int)) );
                 connect( d->verificationJob, SIGNAL(finished(bool)),
                          this, SLOT(slotVerificationFinished(bool)) );
-                connect( d->verificationJob, SIGNAL(debuggingOutput(const QString&, const QString&)),
-                         this, SIGNAL(debuggingOutput(const QString&, const QString&)) );
+                connect( d->verificationJob, SIGNAL(debuggingOutput(QString,QString)),
+                         this, SIGNAL(debuggingOutput(QString,QString)) );
 
             }
             d->verificationJob->setDevice( m_writerDevice );
@@ -965,9 +965,27 @@ QString K3b::DvdCopyJob::jobDetails() const
 }
 
 
+QString K3b::DvdCopyJob::jobSource() const
+{
+    if( Device::Device* device = readingDevice() )
+        return device->vendor() + ' ' + device->description();
+    else
+        return QString();
+}
+
+
+QString K3b::DvdCopyJob::jobTarget() const
+{
+    if( Device::Device* device = writer() )
+        return device->vendor() + ' ' + device->description();
+    else
+        return m_imagePath;
+}
+
+
 void K3b::DvdCopyJob::setVerifyData( bool b )
 {
     d->verifyData = b;
 }
 
-#include "k3bdvdcopyjob.moc"
+
