@@ -21,11 +21,10 @@
 #include "k3bdatatrackreader.h"
 #include "k3bchecksumpipe.h"
 #include "k3biso9660.h"
+#include "k3b_i18n.h"
 
-#include <KDebug>
-#include <KLocale>
-
-#include <QLinkedList>
+#include <QtCore/QDebug>
+#include <QtCore/QLinkedList>
 
 
 namespace {
@@ -130,7 +129,7 @@ K3b::Msf K3b::VerificationJob::Private::trackLength( const TrackEntry& trackEntr
                 trackSize = isoF.primaryDescriptor().volumeSpaceSize;
             }
             else {
-                emit q->infoMessage( i18n("Unable to determine the ISO9660 filesystem size."), MessageError );
+                emit q->infoMessage( i18n("Unable to determine the ISO 9660 filesystem size."), MessageError );
                 return 0;
             }
         }
@@ -150,7 +149,7 @@ K3b::Msf K3b::VerificationJob::Private::trackLength( const TrackEntry& trackEntr
             if( !device->read10( buffer, 2048, track.lastSector().lba(), 1 ) &&
                 !device->read10( buffer, 2048, track.lastSector().lba(), 1 ) ) {
                 trackSize -= 2;
-                kDebug() << "(K3b::CdCopyJob) track " << trackNum << " probably TAO recorded.";
+                qDebug() << "(K3b::CdCopyJob) track " << trackNum << " probably TAO recorded.";
             }
         }
     }
@@ -236,6 +235,21 @@ void K3b::VerificationJob::start()
     emit newTask( i18n("Checking medium") );
 
     d->mediumHasBeenReloaded = false;
+    connect( K3b::Device::sendCommand( K3b::Device::DeviceHandler::CommandLoad, d->device ),
+             SIGNAL(finished(K3b::Device::DeviceHandler*)),
+             this,
+             SLOT(slotMediaLoaded()) );
+}
+
+
+void K3b::VerificationJob::slotMediaLoaded()
+{
+    // we always need to wait for the medium. Otherwise the diskinfo below
+    // may run before the drive is ready!
+    waitForMedium( d->device,
+                   K3b::Device::STATE_COMPLETE|K3b::Device::STATE_INCOMPLETE,
+                   K3b::Device::MEDIA_WRITABLE );
+
     connect( K3b::Device::sendCommand( K3b::Device::DeviceHandler::CommandMediaInfo, d->device ),
              SIGNAL(finished(K3b::Device::DeviceHandler*)),
              this,
@@ -251,7 +265,7 @@ void K3b::VerificationJob::slotDiskInfoReady( K3b::Device::DeviceHandler* dh )
     }
 
     if ( !dh->success() ) {
-        blockingInformation( i18n("Please reload the medium and press 'ok'"),
+        blockingInformation( i18n("Please reload the medium and press 'OK'"),
                              i18n("Failed to reload the medium") );
     }
 
@@ -266,7 +280,7 @@ void K3b::VerificationJob::slotDiskInfoReady( K3b::Device::DeviceHandler* dh )
         if( it->trackNumber == 0 )
             it->trackNumber = d->toc.count();
 
-        if( d->toc.count() < it->trackNumber ) {
+        if( it->trackNumber <= 0 || it->trackNumber > d->toc.count() ) {
             if ( d->mediumHasBeenReloaded ) {
                 emit infoMessage( i18n("Internal Error: Verification job improperly initialized (%1)",
                                        i18n("specified track number '%1' not found on medium", it->trackNumber) ), MessageError );
@@ -324,10 +338,10 @@ void K3b::VerificationJob::readTrack()
             d->dataTrackReader = new K3b::DataTrackReader( this );
             connect( d->dataTrackReader, SIGNAL(percent(int)), this, SLOT(slotReaderProgress(int)) );
             connect( d->dataTrackReader, SIGNAL(finished(bool)), this, SLOT(slotReaderFinished(bool)) );
-            connect( d->dataTrackReader, SIGNAL(infoMessage(const QString&, int)), this, SIGNAL(infoMessage(const QString&, int)) );
-            connect( d->dataTrackReader, SIGNAL(newTask(const QString&)), this, SIGNAL(newSubTask(const QString&)) );
-            connect( d->dataTrackReader, SIGNAL(debuggingOutput(const QString&, const QString&)),
-                     this, SIGNAL(debuggingOutput(const QString&, const QString&)) );
+            connect( d->dataTrackReader, SIGNAL(infoMessage(QString,int)), this, SIGNAL(infoMessage(QString,int)) );
+            connect( d->dataTrackReader, SIGNAL(newTask(QString)), this, SIGNAL(newSubTask(QString)) );
+            connect( d->dataTrackReader, SIGNAL(debuggingOutput(QString,QString)),
+                     this, SIGNAL(debuggingOutput(QString,QString)) );
         }
 
         d->dataTrackReader->setDevice( d->device );
@@ -345,7 +359,7 @@ void K3b::VerificationJob::readTrack()
                                                     isoF.primaryDescriptor().volumeSpaceSize -1 );
             }
             else {
-                emit infoMessage( i18n("Unable to determine the ISO9660 filesystem size."), MessageError );
+                emit infoMessage( i18n("Unable to determine the ISO 9660 filesystem size."), MessageError );
                 jobFinished( false );
                 return;
             }
@@ -400,4 +414,4 @@ void K3b::VerificationJob::slotReaderFinished( bool success )
 }
 
 
-#include "k3bverificationjob.moc"
+
