@@ -19,21 +19,20 @@
 #include "k3bvcdjob.h"
 #include "k3bglobals.h"
 #include "k3bmsf.h"
+#include "k3b_i18n.h"
 
-#include <QDataStream>
-#include <QDomElement>
-#include <QFile>
-#include <QImage>
-#include <QTimer>
+#include <KConfigCore/KConfig>
+#include <KIOCore/KIO/Global>
+#include <KWidgetsAddons/KMessageBox>
+#include <KWidgetsAddons/KStandardGuiItem>
 
-#include <KApplication>
-#include <KConfig>
-#include <KDebug>
-#include <kio/global.h>
-#include <KLocale>
-#include <KMessageBox>
-#include <KStandardDirs>
-#include <KStandardGuiItem>
+#include <QtCore/QDataStream>
+#include <QtCore/QDebug>
+#include <QtCore/QFile>
+#include <QtCore/QTimer>
+#include <QtGui/QImage>
+#include <QtWidgets/QApplication>
+#include <QtXml/QDomElement>
 
 
 #if 0
@@ -53,11 +52,11 @@ K3b::VcdDoc::VcdDoc( QObject* parent )
     m_vcdType = NONE;
 
     m_urlAddingTimer = new QTimer( this );
-    connect( m_urlAddingTimer, SIGNAL( timeout() ), this, SLOT( slotWorkUrlQueue() ) );
+    connect( m_urlAddingTimer, SIGNAL(timeout()), this, SLOT(slotWorkUrlQueue()) );
 
     // FIXME: remove the newTracks() signal and replace it with the changed signal
-    connect( this, SIGNAL( newTracks() ), this, SIGNAL( changed() ) );
-    connect( this, SIGNAL( trackRemoved( K3b::VcdTrack* ) ), this, SIGNAL( changed() ) );
+    connect( this, SIGNAL(newTracks()), this, SIGNAL(changed()) );
+    connect( this, SIGNAL(trackRemoved(K3b::VcdTrack*)), this, SIGNAL(changed()) );
 }
 
 K3b::VcdDoc::~VcdDoc()
@@ -130,22 +129,22 @@ K3b::Msf K3b::VcdDoc::length() const
 }
 
 
-bool K3b::VcdDoc::isImage( const KUrl& url )
+bool K3b::VcdDoc::isImage( const QUrl& url )
 {
     QImage p;
     return p.load( QFile::encodeName( url.toLocalFile() ) );
 }
 
-void K3b::VcdDoc::addUrls( const KUrl::List& urls )
+void K3b::VcdDoc::addUrls( const QList<QUrl>& urls )
 {
     // make sure we add them at the end even if urls are in the queue
     addTracks( urls, 99 );
 }
 
-void K3b::VcdDoc::addTracks( const KUrl::List& urls, uint position )
+void K3b::VcdDoc::addTracks( const QList<QUrl>& urls, uint position )
 {
-    KUrl::List::ConstIterator end( urls.end() );
-    for ( KUrl::List::ConstIterator it = urls.begin(); it != end; ++it ) {
+    QList<QUrl>::ConstIterator end( urls.end() );
+    for ( QList<QUrl>::ConstIterator it = urls.begin(); it != end; ++it ) {
         urlsToAdd.enqueue( new PrivateUrlToAdd( K3b::convertToLocalUrl(*it), position++ ) );
     }
 
@@ -163,12 +162,12 @@ void K3b::VcdDoc::slotWorkUrlQueue()
             lastAddedPosition = m_tracks->count();
 
         if ( !item->url.isLocalFile() ) {
-            kDebug() << item->url.toLocalFile() << " no local file";
+            qDebug() << item->url.toLocalFile() << " no local file";
             return ;
         }
 
         if ( !QFile::exists( item->url.toLocalFile() ) ) {
-            kDebug() << "(K3b::VcdDoc) file not found: " << item->url.toLocalFile();
+            qDebug() << "(K3b::VcdDoc) file not found: " << item->url.toLocalFile();
             m_notFoundFiles.append( item->url.toLocalFile() );
             return ;
         }
@@ -191,7 +190,7 @@ void K3b::VcdDoc::slotWorkUrlQueue()
     }
 }
 
-K3b::VcdTrack* K3b::VcdDoc::createTrack( const KUrl& url )
+K3b::VcdTrack* K3b::VcdDoc::createTrack( const QUrl& url )
 {
     char filename[ 255 ];
     QString error_string = "";
@@ -207,7 +206,7 @@ K3b::VcdTrack* K3b::VcdDoc::createTrack( const KUrl& url )
                 setVcdType( vcdTypes( mpegVersion ) );
                 // FIXME: properly convert the mpeg version
                 vcdOptions() ->setMpegVersion( ( K3b::VcdOptions::MPEGVersion )mpegVersion );
-                KMessageBox::information( kapp->activeWindow(),
+                KMessageBox::information( qApp->activeWindow(),
                                           i18n( "K3b will create a %1 image from the given MPEG "
                                                 "files, but these files must already be in %1 "
                                                 "format. K3b does not yet resample MPEG files.",
@@ -217,7 +216,7 @@ K3b::VcdTrack* K3b::VcdDoc::createTrack( const KUrl& url )
             } else if ( vcdType() == NONE ) {
                 m_urlAddingTimer->stop();
                 vcdOptions() ->setMpegVersion( ( K3b::VcdOptions::MPEGVersion )mpegVersion );
-                bool force = KMessageBox::questionYesNo( kapp->activeWindow(),
+                bool force = KMessageBox::questionYesNo( qApp->activeWindow(),
                                                          i18n( "K3b will create a %1 image from the given MPEG "
                                                                "files, but these files must already be in %1 "
                                                                "format. K3b does not yet resample MPEG files.",
@@ -239,7 +238,7 @@ K3b::VcdTrack* K3b::VcdDoc::createTrack( const KUrl& url )
 
 
             if ( numOfTracks() > 0 && vcdOptions() ->mpegVersion() != mpegVersion ) {
-                KMessageBox::error( kapp->activeWindow(), "(" + url.toLocalFile() + ")\n" +
+                KMessageBox::error( qApp->activeWindow(), '(' + url.toLocalFile() + ")\n" +
                                     i18n( "You cannot mix MPEG1 and MPEG2 video files.\nPlease start a new Project for this filetype.\nResample not implemented in K3b yet." ),
                                     i18n( "Wrong File Type for This Project" ) );
 
@@ -251,9 +250,9 @@ K3b::VcdTrack* K3b::VcdDoc::createTrack( const KUrl& url )
             *( newTrack->mpeg_info ) = *( Mpeg->mpeg_info );
 
             if ( newTrack->isSegment() && !vcdOptions()->PbcEnabled() ) {
-                KMessageBox::information( kapp->activeWindow(),
+                KMessageBox::information( qApp->activeWindow(),
                                           i18n( "PBC (Playback control) enabled.\n"
-                                                "Videoplayers can not reach Segments (Mpeg Still Pictures) without Playback control ." ) ,
+                                                "Video players cannot reach Segments (MPEG Still Pictures) without Playback control." ) ,
                                           i18n( "Information" ) );
 
                 vcdOptions()->setPbcEnabled( true );
@@ -283,7 +282,7 @@ K3b::VcdTrack* K3b::VcdDoc::createTrack( const KUrl& url )
     }
 
     // error (unsupported files)
-    KMessageBox::error( kapp->activeWindow(), "(" + url.toLocalFile() + ")\n" +
+    KMessageBox::error( qApp->activeWindow(), '(' + url.toLocalFile() + ")\n" +
                         i18n( "Only MPEG1 and MPEG2 video files are supported.\n" ) + error_string ,
                         i18n( "Wrong File Format" ) );
 
@@ -291,7 +290,7 @@ K3b::VcdTrack* K3b::VcdDoc::createTrack( const KUrl& url )
     return 0;
 }
 
-void K3b::VcdDoc::addTrack( const KUrl& url, uint position )
+void K3b::VcdDoc::addTrack( const QUrl& url, uint position )
 {
     urlsToAdd.enqueue( new PrivateUrlToAdd( url, position ) );
 
@@ -302,7 +301,7 @@ void K3b::VcdDoc::addTrack( const KUrl& url, uint position )
 void K3b::VcdDoc::addTrack( K3b::VcdTrack* track, uint position )
 {
     if ( m_tracks->count() >= 98 ) {
-        kDebug() << "(K3b::VcdDoc) VCD Green Book only allows 98 tracks.";
+        qDebug() << "(K3b::VcdDoc) VCD Green Book only allows 98 tracks.";
         // TODO: show some messagebox
         delete track;
         return ;
@@ -458,91 +457,91 @@ void K3b::VcdDoc::setPbcTracks()
 
     if ( m_tracks ) {
         int count = m_tracks->count();
-        kDebug() << QString( "K3b::VcdDoc::setPbcTracks() - we have %1 tracks in list." ).arg( count );
+        qDebug() << QString( "K3b::VcdDoc::setPbcTracks() - we have %1 tracks in list." ).arg( count );
 
         Q_FOREACH( K3b::VcdTrack* track, *m_tracks ) {
-            for ( int i = 0; i < K3b::VcdTrack::_maxPbcTracks; i++ ) {
+            Q_FOREACH( VcdTrack::PbcTracks pbc, VcdTrack::trackPlaybackValues() ) {
                 // do not change userdefined tracks
-                if ( !track->isPbcUserDefined( i ) ) {
-                    if ( track->getPbcTrack( i ) )
-                        track->getPbcTrack( i ) ->delFromRevRefList( track );
+                if ( !track->isPbcUserDefined( pbc ) ) {
+                    if ( track->getPbcTrack( pbc ) )
+                        track->getPbcTrack( pbc ) ->delFromRevRefList( track );
 
                     K3b::VcdTrack* t = 0L;
                     int index = track->index();
 
                     // we are the last track
                     if ( index == count - 1 ) {
-                        switch ( i ) {
+                        switch ( pbc ) {
                         case K3b::VcdTrack::PREVIOUS:
                             // we are not alone :)
                             if ( count > 1 ) {
                                 t = m_tracks->at( index - 1 );
                                 t->addToRevRefList( track );
-                                track->setPbcTrack( i, t );
+                                track->setPbcTrack( pbc, t );
                             } else {
-                                track->setPbcTrack( i );
-                                track->setPbcNonTrack( i, K3b::VcdTrack::VIDEOEND );
+                                track->setPbcTrack( pbc );
+                                track->setPbcNonTrack( pbc, K3b::VcdTrack::VIDEOEND );
                             }
                             break;
                         case K3b::VcdTrack::AFTERTIMEOUT:
                         case K3b::VcdTrack::NEXT:
-                            track->setPbcTrack( i );
-                            track->setPbcNonTrack( i, K3b::VcdTrack::VIDEOEND );
+                            track->setPbcTrack( pbc );
+                            track->setPbcNonTrack( pbc, K3b::VcdTrack::VIDEOEND );
                             break;
                         case K3b::VcdTrack::RETURN:
-                            track->setPbcTrack( i );
-                            track->setPbcNonTrack( i, K3b::VcdTrack::VIDEOEND );
+                            track->setPbcTrack( pbc );
+                            track->setPbcNonTrack( pbc, K3b::VcdTrack::VIDEOEND );
                             break;
                         case K3b::VcdTrack::DEFAULT:
-                            track->setPbcTrack( i );
-                            track->setPbcNonTrack( i, K3b::VcdTrack::DISABLED );
+                            track->setPbcTrack( pbc );
+                            track->setPbcNonTrack( pbc, K3b::VcdTrack::DISABLED );
                             break;
                         }
                     }
                     // we are the first track
                     else if ( index == 0 ) {
-                        switch ( i ) {
+                        switch ( pbc ) {
                         case K3b::VcdTrack::PREVIOUS:
-                            track->setPbcTrack( i );
-                            track->setPbcNonTrack( i, K3b::VcdTrack::VIDEOEND );
+                            track->setPbcTrack( pbc );
+                            track->setPbcNonTrack( pbc, K3b::VcdTrack::VIDEOEND );
                             break;
                         case K3b::VcdTrack::AFTERTIMEOUT:
                         case K3b::VcdTrack::NEXT:
                             t = m_tracks->at( index + 1 );
                             t->addToRevRefList( track );
-                            track->setPbcTrack( i, t );
+                            track->setPbcTrack( pbc, t );
                             break;
                         case K3b::VcdTrack::RETURN:
-                            track->setPbcTrack( i );
-                            track->setPbcNonTrack( i, K3b::VcdTrack::VIDEOEND );
+                            track->setPbcTrack( pbc );
+                            track->setPbcNonTrack( pbc, K3b::VcdTrack::VIDEOEND );
                             break;
                         case K3b::VcdTrack::DEFAULT:
-                            track->setPbcTrack( i );
-                            track->setPbcNonTrack( i, K3b::VcdTrack::DISABLED );
+                            track->setPbcTrack( pbc );
+                            track->setPbcNonTrack( pbc, K3b::VcdTrack::DISABLED );
                             break;
                         }
                     }
                     // we are one of the other tracks and have PREVIOUS and NEXT Track
                     else {
-                        switch ( i ) {
+                        switch ( pbc ) {
                         case K3b::VcdTrack::PREVIOUS:
                             t = m_tracks->at( index - 1 );
                             t->addToRevRefList( track );
-                            track->setPbcTrack( i, t );
+                            track->setPbcTrack( pbc, t );
                             break;
                         case K3b::VcdTrack::AFTERTIMEOUT:
                         case K3b::VcdTrack::NEXT:
                             t = m_tracks->at( index + 1 );
                             t->addToRevRefList( track );
-                            track->setPbcTrack( i, t );
+                            track->setPbcTrack( pbc, t );
                             break;
                         case K3b::VcdTrack::RETURN:
-                            track->setPbcTrack( i );
-                            track->setPbcNonTrack( i, K3b::VcdTrack::VIDEOEND );
+                            track->setPbcTrack( pbc );
+                            track->setPbcNonTrack( pbc, K3b::VcdTrack::VIDEOEND );
                             break;
                         case K3b::VcdTrack::DEFAULT:
-                            track->setPbcTrack( i );
-                            track->setPbcNonTrack( i, K3b::VcdTrack::DISABLED );
+                            track->setPbcTrack( pbc );
+                            track->setPbcNonTrack( pbc, K3b::VcdTrack::DISABLED );
                             break;
                         }
                     }
@@ -581,7 +580,7 @@ bool K3b::VcdDoc::loadDocumentData( QDomElement* root )
         QDomNode item = vcdNodes.item( i );
         QString name = item.nodeName();
 
-        kDebug() << QString( "(K3b::VcdDoc::loadDocumentData) nodeName = '%1'" ).arg( name );
+        qDebug() << QString( "(K3b::VcdDoc::loadDocumentData) nodeName = '%1'" ).arg( name );
 
         if ( name == "volumeId" )
             vcdOptions() ->setVolumeId( item.toElement().text() );
@@ -638,7 +637,7 @@ bool K3b::VcdDoc::loadDocumentData( QDomElement* root )
     // vcd Tracks
     QDomNodeList trackNodes = nodes.item( 2 ).childNodes();
 
-    for ( uint i = 0; i < trackNodes.length(); i++ ) {
+    for ( int i = 0; i < trackNodes.length(); i++ ) {
 
         // check if url is available
         QDomElement trackElem = trackNodes.item( i ).toElement();
@@ -646,7 +645,7 @@ bool K3b::VcdDoc::loadDocumentData( QDomElement* root )
         if ( !QFile::exists( url ) )
             m_notFoundFiles.append( url );
         else {
-            KUrl k;
+            QUrl k;
             k.setPath( url );
             if ( K3b::VcdTrack * track = createTrack( k ) ) {
                 track ->setPlayTime( trackElem.attribute( "playtime", "1" ).toInt() );
@@ -665,22 +664,22 @@ bool K3b::VcdDoc::loadDocumentData( QDomElement* root )
     // do not add saved pbcTrack links when one ore more files missing.
     // TODO: add info message to informAboutNotFoundFiles();
     if ( m_notFoundFiles.isEmpty() ) {
-        int type;
-        int val;
+        VcdTrack::PbcTracks type;
+        VcdTrack::PbcTypes val;
         bool pbctrack;
-        for ( uint trackId = 0; trackId < trackNodes.length(); trackId++ ) {
+        for ( int trackId = 0; trackId < trackNodes.length(); trackId++ ) {
             QDomElement trackElem = trackNodes.item( trackId ).toElement();
             QDomNodeList trackNodes = trackElem.childNodes();
-            for ( uint i = 0; i < trackNodes.length(); i++ ) {
+            for ( int i = 0; i < trackNodes.length(); i++ ) {
                 QDomElement trackElem = trackNodes.item( i ).toElement();
                 QString name = trackElem.tagName();
                 if ( name.contains( "pbc" ) ) {
                     if ( trackElem.hasAttribute ( "type" ) ) {
-                        type = trackElem.attribute ( "type" ).toInt();
+                        type = static_cast<VcdTrack::PbcTracks>( trackElem.attribute ( "type" ).toInt() );
                         if ( trackElem.hasAttribute ( "pbctrack" ) ) {
                             pbctrack = ( trackElem.attribute ( "pbctrack" ) == "yes" );
                             if ( trackElem.hasAttribute ( "val" ) ) {
-                                val = trackElem.attribute ( "val" ).toInt();
+                                val = static_cast<VcdTrack::PbcTypes>( trackElem.attribute ( "val" ).toInt() );
                                 K3b::VcdTrack* track = m_tracks->at( trackId );
                                 K3b::VcdTrack* pbcTrack = m_tracks->at( val );
                                 if ( pbctrack ) {
@@ -850,19 +849,17 @@ bool K3b::VcdDoc::saveDocumentData( QDomElement * docElem )
         trackElem.setAttribute( "numkeys", ( track->PbcNumKeys() ) ? "yes" : "no" );
         trackElem.setAttribute( "userdefinednumkeys", ( track->PbcNumKeysUserdefined() ) ? "yes" : "no" );
 
-        for ( int i = 0;
-              i < K3b::VcdTrack::_maxPbcTracks;
-              i++ ) {
-            if ( track->isPbcUserDefined( i ) ) {
+        Q_FOREACH( VcdTrack::PbcTracks pbc, VcdTrack::trackPlaybackValues() ) {
+            if ( track->isPbcUserDefined( pbc ) ) {
                 // save pbcTracks
                 QDomElement pbcElem = doc.createElement( "pbc" );
-                pbcElem.setAttribute( "type", i );
-                if ( track->getPbcTrack( i ) ) {
+                pbcElem.setAttribute( "type", pbc );
+                if ( track->getPbcTrack( pbc ) ) {
                     pbcElem.setAttribute( "pbctrack", "yes" );
-                    pbcElem.setAttribute( "val", track->getPbcTrack( i ) ->index() );
+                    pbcElem.setAttribute( "val", track->getPbcTrack( pbc ) ->index() );
                 } else {
                     pbcElem.setAttribute( "pbctrack", "no" );
-                    pbcElem.setAttribute( "val", track->getNonPbcTrack( i ) );
+                    pbcElem.setAttribute( "val", track->getNonPbcTrack( pbc ) );
                 }
                 trackElem.appendChild( pbcElem );
             }
@@ -899,4 +896,4 @@ K3b::Device::MediaTypes K3b::VcdDoc::supportedMediaTypes() const
     return K3b::Device::MEDIA_WRITABLE_CD;
 }
 
-#include "k3bvcddoc.moc"
+
