@@ -14,17 +14,17 @@
 
 #include "k3bcddb.h"
 #include "k3bmedium.h"
-
 #include "k3btoc.h"
+#include "k3b_i18n.h"
 
-#include <QtGui/QVBoxLayout>
-#include <QtGui/QListWidget>
-#include <QtGui/QLabel>
-#include <QtGui/QApplication>
+#include <QtWidgets/QApplication>
+#include <QtWidgets/QDialog>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QVBoxLayout>
+#include <QtWidgets/QListWidget>
+#include <QtWidgets/QLabel>
 
-#include <KLocale>
-
-#include <libkcddb/client.h>
+#include <KCddb/Client>
 
 
 KCDDB::TrackOffsetList K3b::CDDB::createTrackOffsetList( const K3b::Device::Toc& toc )
@@ -38,56 +38,46 @@ KCDDB::TrackOffsetList K3b::CDDB::createTrackOffsetList( const K3b::Device::Toc&
 }
 
 
-K3b::CDDB::MultiEntriesDialog::MultiEntriesDialog( QWidget* parent )
-    : KDialog( parent )
-{
-    setCaption( i18n("Multiple CDDB Entries Found") );
-    setButtons( Ok|Cancel );
-
-    QWidget* frame = mainWidget();
-
-    QLabel* infoLabel = new QLabel( i18n("K3b found multiple or inexact CDDB entries. Please select one."), frame );
-    infoLabel->setWordWrap( true );
-
-    m_listBox = new QListWidget( frame );
-    m_listBox->setSelectionMode( QAbstractItemView::SingleSelection );
-
-    QVBoxLayout* layout = new QVBoxLayout( frame );
-    layout->setMargin( 0 );
-    layout->addWidget( infoLabel );
-    layout->addWidget( m_listBox );
-
-    setMinimumSize( 280, 200 );
-}
-
-
 int K3b::CDDB::MultiEntriesDialog::selectCddbEntry( const KCDDB::CDInfoList& entries, QWidget* parent )
 {
-    MultiEntriesDialog d( parent );
+    QDialog dialog( parent );
+    dialog.setWindowTitle( i18n("Multiple CDDB Entries Found") );
+
+    QLabel* infoLabel = new QLabel( i18n("K3b found multiple or inexact CDDB entries. Please select one."), &dialog );
+    infoLabel->setWordWrap( true );
+
+    QListWidget* listBox = new QListWidget( &dialog );
+    listBox->setSelectionMode( QAbstractItemView::SingleSelection );
+
+    QDialogButtonBox* buttonBox = new QDialogButtonBox( QDialogButtonBox::Ok | QDialogButtonBox::Cancel, &dialog );
+    QObject::connect( buttonBox, SIGNAL(accepted()), &dialog, SLOT(accept()) );
+    QObject::connect( buttonBox, SIGNAL(rejected()), &dialog, SLOT(reject()) );
+
+    QVBoxLayout* layout = new QVBoxLayout( &dialog );
+    layout->setContentsMargins( 0, 0, 0, 0 );
+    layout->addWidget( infoLabel );
+    layout->addWidget( listBox );
+    layout->addWidget( buttonBox );
+
+    dialog.setMinimumSize( 280, 200 );
 
     int i = 1;
     foreach( const KCDDB::CDInfo& info, entries ) {
-        d.m_listBox->addItem( QString::number(i++) + " " +
+        listBox->addItem( QString::number(i++) + ' ' +
                               info.get( KCDDB::Artist ).toString() + " - " +
                               info.get( KCDDB::Title ).toString() + " (" +
-                              info.get( KCDDB::Category ).toString() + ")" );
+                              info.get( KCDDB::Category ).toString() + ')' );
     }
 
-    d.m_listBox->setCurrentRow( 0 );
+    listBox->setCurrentRow( 0 );
 
-    if( d.exec() == QDialog::Accepted )
-        return d.m_listBox->currentRow();
+    if( dialog.exec() == QDialog::Accepted )
+        return listBox->currentRow();
     else
         return -1;
 }
 
 
-K3b::CDDB::MultiEntriesDialog::~MultiEntriesDialog()
-{
-}
-
-
-
 class K3b::CDDB::CDDBJob::Private
 {
 public:
@@ -135,8 +125,8 @@ K3b::CDDB::CDDBJob::CDDBJob( QObject* parent )
 {
     d->q = this;
     d->cddbClient.setBlockingMode( false );
-    connect( &d->cddbClient, SIGNAL( finished( KCDDB::Result ) ),
-             this, SLOT( _k_cddbQueryFinished( KCDDB::Result ) ) );
+    connect( &d->cddbClient, SIGNAL(finished(KCDDB::Result)),
+             this, SLOT(_k_cddbQueryFinished(KCDDB::Result)) );
 }
 
 
@@ -154,7 +144,7 @@ K3b::Medium K3b::CDDB::CDDBJob::medium() const
 
 void K3b::CDDB::CDDBJob::start()
 {
-    kDebug();
+    qDebug();
     d->cddbInfo.clear();
     d->cddbClient.lookup( createTrackOffsetList( d->toc ) );
 }
@@ -186,4 +176,4 @@ K3b::CDDB::CDDBJob* K3b::CDDB::CDDBJob::queryCddb( const K3b::Device::Toc& toc )
     return job;
 }
 
-#include "k3bcddb.moc"
+#include "moc_k3bcddb.cpp"
