@@ -21,81 +21,20 @@
 #include "k3btoc.h"
 #include "k3bmsf.h"
 
-#include <KDebug>
+#include <QtCore/QDebug>
+#include <QtCore/QFile>
+#include <QtCore/QGlobalStatic>
+#include <QtCore/QLibrary>
+#include <QtCore/QMutex>
+#include <QtCore/QMutexLocker>
 
-// TODO replace dlopen/dlsym/dlclose by platform independent QLibrary
 #ifdef Q_OS_WIN32
-
-#include <QLibrary>
-
-inline void *dlopen(char *fileName, int b)
-{
-	static QLibrary lib;
-	lib.setFileName(fileName);
-	if (lib.isLoaded())
-		return &lib;
-	if (lib.load())
-		return &lib;
-	return 0;
-}
-
-inline void *dlsym(void *a, const char *b)
-{
-	QLibrary *lib = (QLibrary *)a;
-	return lib->resolve(b);
-}
-
-inline void dlclose(void *a)
-{
-	QLibrary *lib = (QLibrary *)a;
-	lib->unload();
-}
-
-#define RTLD_GLOBAL 0
-#define RTLD_NOW 0
-#define RTLD_LAZY 0
-
 typedef short int int16_t;
-#else
-#include <dlfcn.h>
-#endif
-
-#include <QFile>
-#include <QMutex>
-#include <QMutexLocker>
-
-#ifdef Q_OS_WIN32
-#define LIBCDIO_CDDA "cdio_cdda.dll"
-#define LIBCDIO_PARANOIA "cdio_paranoia.dll"
-#else
-#ifdef __NETBSD__
-#define CDDA_LIBCDDA_INTERFACE "cdda/libcdda_interace.so"
-#define CDDA_LIBCDDA_PARANOIA "cdda/libcdda_paranoia.so"
-#define LIBCDDA_INTERFACE "libcdda_interface.so"
-#define LIBCDDA_PARANOIA "libcdda_paranoia.so"
-#define LIBCDIO_CDDA "libcdio_cdda.so"
-#define LIBCDIO_PARANOIA "libcdio_paranoia.so"
-#else
-#define CDDA_LIBCDDA_INTERFACE "cdda/libcdda_interace.so.0"
-#define CDDA_LIBCDDA_PARANOIA "cdda/libcdda_paranoia.so.0"
-#define LIBCDDA_INTERFACE "libcdda_interface.so.0"
-#define LIBCDDA_PARANOIA "libcdda_paranoia.so.0"
-#define LIBCDIO_CDDA "libcdio_cdda.so.2"
-#define LIBCDIO_CDDA_0 "libcdio_cdda.so.0"
-#define LIBCDIO_CDDA_1 "libcdio_cdda.so.1"
-#define LIBCDIO_PARANOIA "libcdio_paranoia.so.2"
-#define LIBCDIO_PARANOIA_0 "libcdio_paranoia.so.0"
-#define LIBCDIO_PARANOIA_1 "libcdio_paranoia.so.1"
-#endif
 #endif
 
 static bool s_haveLibCdio = false;
 
 
-void* K3b::CdparanoiaLib::s_libInterface = 0;
-void* K3b::CdparanoiaLib::s_libParanoia = 0;
-int K3b::CdparanoiaLib::s_counter = 0;
-
 
 #define CDDA_IDENTIFY          s_haveLibCdio ? "cdio_cddap_identify" : "cdda_identify"
 #define CDDA_CLOSE             s_haveLibCdio ? "cdio_cddap_close" : "cdda_close"
@@ -128,6 +67,10 @@ int K3b::CdparanoiaLib::s_counter = 0;
 #define PARANOIA_CB_READERR       12
 
 
+Q_GLOBAL_STATIC(QLibrary, s_libInterface)
+Q_GLOBAL_STATIC(QLibrary, s_libParanoia)
+
+
 
 static void paranoiaCallback( long, int status )
 {
@@ -451,90 +394,79 @@ public:
 K3b::CdparanoiaLib::CdparanoiaLib()
 {
     d = new Private();
-    s_counter++;
 }
 
 
 K3b::CdparanoiaLib::~CdparanoiaLib()
 {
     delete d;
-    s_counter--;
-    if( s_counter == 0 ) {
-        K3b::CdparanoiaLibData::freeAll();
-
-        // cleanup the dynamically loaded lib
-        dlclose( s_libInterface );
-        dlclose( s_libParanoia );
-        s_libInterface = 0;
-        s_libParanoia = 0;
-    }
 }
 
 
 bool K3b::CdparanoiaLib::load()
 {
-    cdda_cdda_identify = (cdrom_drive* (*) (const char*, int, char**))dlsym( s_libInterface, CDDA_IDENTIFY );
-    cdda_cdda_open = (int (*) (cdrom_drive*))dlsym( s_libInterface, CDDA_OPEN );
-    cdda_cdda_close = (int (*) (cdrom_drive*))dlsym( s_libInterface, CDDA_CLOSE );
-    cdda_cdda_track_firstsector = (long (*)(cdrom_drive*, int))dlsym( s_libInterface, CDDA_TRACK_FIRSTSECTOR );
-    cdda_cdda_track_lastsector = (long (*)(cdrom_drive*, int))dlsym( s_libInterface, CDDA_TRACK_LASTSECTOR );
-    cdda_cdda_verbose_set = (void (*)(cdrom_drive *d,int err_action, int mes_action))dlsym( s_libInterface, CDDA_VERBOSE_SET );
-    cdda_cdda_disc_firstsector = (long (*)(cdrom_drive *d))dlsym( s_libInterface, CDDA_DISC_FIRSTSECTOR );
+    cdda_cdda_identify = (cdrom_drive* (*) (const char*, int, char**))s_libInterface->resolve( CDDA_IDENTIFY );
+    cdda_cdda_open = (int (*) (cdrom_drive*))s_libInterface->resolve( CDDA_OPEN );
+    cdda_cdda_close = (int (*) (cdrom_drive*))s_libInterface->resolve( CDDA_CLOSE );
+    cdda_cdda_track_firstsector = (long (*)(cdrom_drive*, int))s_libInterface->resolve( CDDA_TRACK_FIRSTSECTOR );
+    cdda_cdda_track_lastsector = (long (*)(cdrom_drive*, int))s_libInterface->resolve( CDDA_TRACK_LASTSECTOR );
+    cdda_cdda_verbose_set = (void (*)(cdrom_drive *d,int err_action, int mes_action))s_libInterface->resolve( CDDA_VERBOSE_SET );
+    cdda_cdda_disc_firstsector = (long (*)(cdrom_drive *d))s_libInterface->resolve( CDDA_DISC_FIRSTSECTOR );
 
-    cdda_paranoia_init = (cdrom_paranoia* (*)(cdrom_drive*))dlsym( s_libParanoia, PARANOIA_INIT );
-    cdda_paranoia_free = (void (*)(cdrom_paranoia *p))dlsym( s_libParanoia, PARANOIA_FREE );
-    cdda_paranoia_modeset = (void (*)(cdrom_paranoia *p, int mode))dlsym( s_libParanoia, PARANOIA_MODESET );
-    cdda_paranoia_read_limited = (int16_t* (*)(cdrom_paranoia *p, void(*callback)(long,int), int))dlsym( s_libParanoia, PARANOIA_READ_LIMITED );
-    cdda_paranoia_seek = (long (*)(cdrom_paranoia *p,long seek,int mode))dlsym( s_libParanoia, PARANOIA_SEEK );
+    cdda_paranoia_init = (cdrom_paranoia* (*)(cdrom_drive*))s_libParanoia->resolve( PARANOIA_INIT );
+    cdda_paranoia_free = (void (*)(cdrom_paranoia *p))s_libParanoia->resolve( PARANOIA_FREE );
+    cdda_paranoia_modeset = (void (*)(cdrom_paranoia *p, int mode))s_libParanoia->resolve( PARANOIA_MODESET );
+    cdda_paranoia_read_limited = (int16_t* (*)(cdrom_paranoia *p, void(*callback)(long,int), int))s_libParanoia->resolve( PARANOIA_READ_LIMITED );
+    cdda_paranoia_seek = (long (*)(cdrom_paranoia *p,long seek,int mode))s_libParanoia->resolve( PARANOIA_SEEK );
 
     // check if all symbols could be resoled
     if( cdda_cdda_identify == 0 ) {
-        kDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'cdda_identify'";
+        qDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'cdda_identify'";
         return false;
     }
     if( cdda_cdda_open == 0 ) {
-        kDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'cdda_open'";
+        qDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'cdda_open'";
         return false;
     }
     if( cdda_cdda_close == 0 ) {
-        kDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'cdda_close'";
+        qDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'cdda_close'";
         return false;
     }
     if( cdda_cdda_track_firstsector == 0 ) {
-        kDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'cdda_track_firstsector'";
+        qDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'cdda_track_firstsector'";
         return false;
     }
     if( cdda_cdda_track_lastsector == 0 ) {
-        kDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'cdda_track_lastsector'";
+        qDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'cdda_track_lastsector'";
         return false;
     }
     if( cdda_cdda_disc_firstsector == 0 ) {
-        kDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'cdda_disc_firstsector'";
+        qDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'cdda_disc_firstsector'";
         return false;
     }
     if( cdda_cdda_verbose_set == 0 ) {
-        kDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'cdda_verbose_set'";
+        qDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'cdda_verbose_set'";
         return false;
     }
 
     if( cdda_paranoia_init == 0 ) {
-        kDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'paranoia_init'";
+        qDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'paranoia_init'";
         return false;
     }
     if( cdda_paranoia_free == 0 ) {
-        kDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'paranoia_free'";
+        qDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'paranoia_free'";
         return false;
     }
     if( cdda_paranoia_modeset == 0 ) {
-        kDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'paranoia_modeset'";
+        qDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'paranoia_modeset'";
         return false;
     }
     if( cdda_paranoia_read_limited == 0 ) {
-        kDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'paranoia_read_limited'";
+        qDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'paranoia_read_limited'";
         return false;
     }
     if( cdda_paranoia_seek == 0 ) {
-        kDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'paranoia_seek'";
+        qDebug() << "(K3b::CdparanoiaLib) Error: could not resolve 'paranoia_seek'";
         return false;
     }
 
@@ -546,68 +478,86 @@ bool K3b::CdparanoiaLib::load()
 K3b::CdparanoiaLib* K3b::CdparanoiaLib::create()
 {
     // check if libcdda_interface is avalilable
-    if( !s_libInterface ) {
-#ifndef Q_OS_WIN32
+    if( !s_libInterface->isLoaded() ) {
         s_haveLibCdio = true;
-#endif
-
-        s_libInterface = dlopen( LIBCDIO_CDDA, RTLD_NOW|RTLD_GLOBAL );
 
+        // Windows ignores version:
+        // http://qt-project.org/doc/qt-4.8/qlibrary.html#setFileNameAndVersion
+        s_libInterface->setFileNameAndVersion( "cdio_cdda", 2 );
+        s_libInterface->setLoadHints( QLibrary::ResolveAllSymbolsHint | QLibrary::ExportExternalSymbolsHint );
 #ifndef Q_OS_WIN32
-        if( !s_libInterface ) {
-#ifndef __NETBSD__
-            s_libInterface = dlopen( LIBCDIO_CDDA_1, RTLD_NOW|RTLD_GLOBAL );
-            if( !s_libInterface ) {
-                s_libInterface = dlopen( LIBCDIO_CDDA_0, RTLD_NOW|RTLD_GLOBAL );
-                if( !s_libInterface ) {
+        if( !s_libInterface->load() ) {
+            s_libInterface->setFileNameAndVersion( "cdio_cdda", 1 );
+            if( !s_libInterface->load() ) {
+                s_libInterface->setFileNameAndVersion( "cdio_cdda", 0 );
+                if( !s_libInterface->load() ) {
+                    s_libInterface->setFileNameAndVersion( "cdio_cdda", "" );
+                    if( !s_libInterface->load() ) {
+                        s_haveLibCdio = false;
+                        s_libInterface->setFileNameAndVersion( "cdda_interface", 1 );
+                        if( !s_libInterface->load() ) {
+                            s_libInterface->setFileNameAndVersion( "cdda_interface", 0 );
 #endif
-                    s_haveLibCdio = false;
-                    s_libInterface = dlopen( LIBCDDA_INTERFACE, RTLD_NOW|RTLD_GLOBAL );
-                    // try the redhat & Co. location
-                    if( !s_libInterface )
-                        s_libInterface = dlopen( CDDA_LIBCDDA_INTERFACE, RTLD_NOW|RTLD_GLOBAL );
-#ifndef __NETBSD__
+                            if( !s_libInterface->load() ) {
+                                s_libInterface->setFileNameAndVersion( "cdda_interface", "" );
+                                if( !s_libInterface->load() ) {
+                                    qDebug() << "(K3b::CdparanoiaLib) Error while loading libcdda_interface.";
+                                    return 0;
+                                }
+                            }
+#ifndef Q_OS_WIN32
+                        }
+                    }
+                }
+            }
+        }
+#endif
+
+
+	s_libParanoia->setLoadHints( QLibrary::ResolveAllSymbolsHint | QLibrary::ExportExternalSymbolsHint );
+        if( s_haveLibCdio ) {
+            s_libParanoia->setFileNameAndVersion( "cdio_paranoia", 2 );
+#ifndef Q_OS_WIN32
+            if( !s_libParanoia->load() ) {
+                s_libParanoia->setFileNameAndVersion( "cdio_paranoia", 1 );
+                if( !s_libParanoia->load() ) {
+                    s_libParanoia->setFileNameAndVersion( "cdio_paranoia", 0 );
+                    if( !s_libParanoia->load() ) {
+                        s_libParanoia->setFileNameAndVersion( "cdio_paranoia", "" );
+#endif
+                        s_libParanoia->load();
+#ifndef Q_OS_WIN32
+                    }
                 }
             }
 #endif
         }
-#endif
-
-        if( !s_libInterface ) {
-            kDebug() << "(K3b::CdparanoiaLib) Error while loading libcdda_interface. ";
-            return 0;
-        }
 
+        if( !s_libParanoia->isLoaded() ) {
+            s_libParanoia->setFileNameAndVersion( "cdda_paranoia", 1 );
 #ifndef Q_OS_WIN32
-        if( s_haveLibCdio ) {
-            s_libParanoia = dlopen( LIBCDIO_PARANOIA, RTLD_NOW );
-#ifndef __NETBSD__
-            if( !s_libParanoia ) {
-                s_libParanoia = dlopen( LIBCDIO_PARANOIA_1, RTLD_NOW );
-                if( !s_libParanoia )
-                    s_libParanoia = dlopen( LIBCDIO_PARANOIA_0, RTLD_NOW );
+            if( !s_libParanoia->load() ) {
+                s_libParanoia->setFileNameAndVersion( "cdda_paranoia", 0 );
+                if( !s_libParanoia->load() ) {
+                    s_libParanoia->setFileNameAndVersion( "cdda_paranoia", "" );
+#endif
+                    if( !s_libParanoia->load() ) {
+                        qDebug() << "(K3b::CdparanoiaLib) Error while loading libcdda_paranoia.";
+                        s_libInterface->unload();
+                        return 0;
+                    }
+#ifndef Q_OS_WIN32
+                }
             }
-        } else {
-            s_libParanoia = dlopen( LIBCDDA_PARANOIA, RTLD_NOW );
-            if( !s_libParanoia )
-                s_libParanoia = dlopen( CDDA_LIBCDDA_PARANOIA, RTLD_NOW );
 #endif
         }
-#else
-        s_libParanoia = dlopen( LIBCDIO_PARANOIA, RTLD_NOW );
-#endif
-
-        if( !s_libParanoia ) {
-            kDebug() << "(K3b::CdparanoiaLib) Error while loading libcdda_paranoia. ";
-            dlclose( s_libInterface );
-            s_libInterface = 0;
-            return 0;
-        }
     }
 
     K3b::CdparanoiaLib* lib = new K3b::CdparanoiaLib();
     if( !lib->load() ) {
-        kDebug() << "(K3b::CdparanoiaLib) Error: could not resolve all symbols!";
+        qDebug() << "(K3b::CdparanoiaLib) Error: could not resolve all symbols!";
+        s_libInterface->unload();
+        s_libParanoia->unload();
         delete lib;
         return 0;
     }
@@ -618,7 +568,7 @@ K3b::CdparanoiaLib* K3b::CdparanoiaLib::create()
 bool K3b::CdparanoiaLib::initParanoia( K3b::Device::Device* dev, const K3b::Device::Toc& toc )
 {
     if( !dev ) {
-        kError() << "(K3b::CdparanoiaLib::initParanoia) dev = 0!" << endl;
+        qCritical() << "(K3b::CdparanoiaLib::initParanoia) dev = 0!" << endl;
         return false;
     }
 
@@ -627,13 +577,13 @@ bool K3b::CdparanoiaLib::initParanoia( K3b::Device::Device* dev, const K3b::Devi
     d->device = dev;
     d->toc = toc;
     if( d->toc.isEmpty() ) {
-        kDebug() << "(K3b::CdparanoiaLib) empty toc.";
+        qDebug() << "(K3b::CdparanoiaLib) empty toc.";
         cleanup();
         return false;
     }
 
     if( d->toc.contentType() == K3b::Device::DATA ) {
-        kDebug() << "(K3b::CdparanoiaLib) No audio tracks found.";
+        qDebug() << "(K3b::CdparanoiaLib) No audio tracks found.";
         cleanup();
         return false;
     }
@@ -697,7 +647,7 @@ bool K3b::CdparanoiaLib::initReading()
         return initReading( start, end );
     }
     else {
-        kDebug() << "(K3b::CdparanoiaLib) initReading without initParanoia.";
+        qDebug() << "(K3b::CdparanoiaLib) initReading without initParanoia.";
         return false;
     }
 }
@@ -712,17 +662,17 @@ bool K3b::CdparanoiaLib::initReading( int track )
                 return initReading( k3bTrack.firstSector().lba(), k3bTrack.lastSector().lba() );
             }
             else {
-                kDebug() << "(K3b::CdparanoiaLib) Track " << track << " no audio track.";
+                qDebug() << "(K3b::CdparanoiaLib) Track " << track << " no audio track.";
                 return false;
             }
         }
         else {
-            kDebug() << "(K3b::CdparanoiaLib) Track " << track << " too high.";
+            qDebug() << "(K3b::CdparanoiaLib) Track " << track << " too high.";
             return false;
         }
     }
     else {
-        kDebug() << "(K3b::CdparanoiaLib) initReading without initParanoia.";
+        qDebug() << "(K3b::CdparanoiaLib) initReading without initParanoia.";
         return false;
     }
 }
@@ -730,7 +680,7 @@ bool K3b::CdparanoiaLib::initReading( int track )
 
 bool K3b::CdparanoiaLib::initReading( long start, long end )
 {
-    kDebug() << "(K3b::CdparanoiaLib) initReading( " << start << ", " << end << " )";
+    qDebug() << "(K3b::CdparanoiaLib) initReading( " << start << ", " << end << " )";
 
     if( d->device ) {
         if( d->toc.firstSector().lba() <= start &&
@@ -748,12 +698,12 @@ bool K3b::CdparanoiaLib::initReading( long start, long end )
             return true;
         }
         else {
-            kDebug() << "(K3b::CdparanoiaLib) " << start << " and " << end << " out of range.";
+            qDebug() << "(K3b::CdparanoiaLib) " << start << " and " << end << " out of range.";
             return false;
         }
     }
     else {
-        kDebug() << "(K3b::CdparanoiaLib) initReading without initParanoia.";
+        qDebug() << "(K3b::CdparanoiaLib) initReading without initParanoia.";
         return false;
     }
 }
@@ -762,7 +712,7 @@ bool K3b::CdparanoiaLib::initReading( long start, long end )
 char* K3b::CdparanoiaLib::read( int* statusCode, unsigned int* track, bool littleEndian )
 {
     if( d->currentSector > d->lastSector ) {
-        kDebug() << "(K3b::CdparanoiaLib) finished ripping. read "
+        qDebug() << "(K3b::CdparanoiaLib) finished ripping. read "
                  << (d->currentSector - d->startSector) << " sectors." << endl
                  << "                   current sector: " << d->currentSector << endl;
         d->status = S_OK;
@@ -772,7 +722,7 @@ char* K3b::CdparanoiaLib::read( int* statusCode, unsigned int* track, bool littl
     }
 
     if( d->currentSector != d->data->sector() ) {
-        kDebug() << "(K3b::CdparanoiaLib) need to seek before read. Looks as if we are reusing the paranoia instance.";
+        qDebug() << "(K3b::CdparanoiaLib) need to seek before read. Looks as if we are reusing the paranoia instance.";
         if( d->data->paranoiaSeek( d->currentSector, SEEK_SET ) == -1 )
             return 0;
     }
