@@ -14,21 +14,17 @@
 
 #include "k3bmultichoicedialog.h"
 #include "k3bstdguiitems.h"
-#include "k3brichtextlabel.h"
 
-#include <kpushbutton.h>
-#include <kapplication.h>
-#include <kiconloader.h>
-#include <KDialog>
+#include <KIconThemes/KIconLoader>
 
-#include <qlayout.h>
-#include <qsignalmapper.h>
-#include <qlabel.h>
-#include <qmessagebox.h>
-#include <QPixmap>
-#include <QGridLayout>
-#include <QHBoxLayout>
-#include <QCloseEvent>
+#include <QtCore/QSignalMapper>
+#include <QtGui/QCloseEvent>
+#include <QtWidgets/QGridLayout>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLayout>
+#include <QtWidgets/QMessageBox>
+#include <QtWidgets/QPushButton>
 
 
 class K3b::MultiChoiceDialog::Private
@@ -40,7 +36,7 @@ public:
     }
 
     QSignalMapper* mapper;
-    QList<KPushButton*> buttons;
+    QList<QPushButton*> buttons;
     QHBoxLayout* buttonLayout;
 
     bool buttonClicked;
@@ -54,7 +50,7 @@ static QIcon themedMessageBoxIcon(QMessageBox::Icon icon)
 
     switch (icon) {
     case QMessageBox::NoIcon:
-        return QPixmap();
+        return QIcon();
         break;
     case QMessageBox::Information:
         icon_name = "dialog-information";
@@ -94,19 +90,20 @@ K3b::MultiChoiceDialog::MultiChoiceDialog( const QString& caption,
     QGridLayout* mainGrid = new QGridLayout( this );
 
     QHBoxLayout* contents = new QHBoxLayout;
-    contents->setSpacing( KDialog::spacingHint()*2 );
-    contents->setMargin( 0 );
+    contents->setSpacing( contents->spacing()*2 );
+    contents->setContentsMargins( 0, 0, 0, 0 );
 
     QLabel* pixLabel = new QLabel( this );
     int size = IconSize(KIconLoader::Dialog);
     pixLabel->setPixmap( themedMessageBoxIcon( icon ).pixmap( size, size ) );
     pixLabel->setScaledContents( false );
-    QLabel* label = new K3b::RichTextLabel( text, this );
+    QLabel* label = new QLabel( text, this );
+    label->setWordWrap( true );
     contents->addWidget( pixLabel, 0 );
     contents->addWidget( label, 1 );
 
     d->buttonLayout = new QHBoxLayout;
-    d->buttonLayout->setMargin( 0 );
+    d->buttonLayout->setContentsMargins( 0, 0, 0, 0 );
 
     mainGrid->addLayout( contents, 0, 0, 1, 3 );
     mainGrid->addWidget( K3b::StdGuiItems::horizontalLine( this ), 1, 0, 1, 3 );
@@ -126,7 +123,8 @@ K3b::MultiChoiceDialog::~MultiChoiceDialog()
 
 int K3b::MultiChoiceDialog::addButton( const KGuiItem& b )
 {
-    KPushButton* button = new KPushButton( b, this );
+    QPushButton* button = new QPushButton( this );
+    KGuiItem::assign( button, b );
     d->buttonLayout->addWidget( button );
     d->buttons.append(button);
     d->mapper->setMapping( button, d->buttons.count() );
@@ -190,4 +188,4 @@ int K3b::MultiChoiceDialog::choose( const QString& caption,
 }
 
 
-#include "k3bmultichoicedialog.moc"
+
