@@ -21,28 +21,26 @@
 
 #include <config-k3b.h>
 
-#include "kdebug.h"
-
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qfile.h>
-#include <qfileinfo.h>
-#include <qregexp.h>
-
-#include <kapplication.h>
-#include <kconfig.h>
-#include <kconfiggroup.h>
-#include <ktemporaryfile.h>
+#include <KConfigCore/KConfig>
+#include <KConfigCore/KConfigGroup>
 
 #include <Solid/DeviceNotifier>
 #include <Solid/DeviceInterface>
 #include <Solid/OpticalDrive>
 #include <Solid/Block>
 #include <Solid/Device>
-#ifdef __NETBSD__
+#ifdef Q_OS_NETBSD
 #include <Solid/GenericInterface>
 #endif
 
+#include <QtCore/QDebug>
+#include <QtCore/QString>
+#include <QtCore/QStringList>
+#include <QtCore/QFile>
+#include <QtCore/QFileInfo>
+#include <QtCore/QRegExp>
+#include <QtCore/QTemporaryFile>
+
 #include <iostream>
 #include <limits.h>
 #include <assert.h>
@@ -132,10 +130,10 @@ K3b::Device::DeviceManager::DeviceManager( QObject* parent )
     : QObject( parent ),
       d( new Private() )
 {
-    connect( Solid::DeviceNotifier::instance(), SIGNAL( deviceAdded( const QString& ) ),
-             this, SLOT( slotSolidDeviceAdded( const QString& ) ) );
-    connect( Solid::DeviceNotifier::instance(), SIGNAL( deviceRemoved( const QString& ) ),
-             this, SLOT( slotSolidDeviceRemoved( const QString& ) ) );
+    connect( Solid::DeviceNotifier::instance(), SIGNAL(deviceAdded(QString)),
+             this, SLOT(slotSolidDeviceAdded(QString)) );
+    connect( Solid::DeviceNotifier::instance(), SIGNAL(deviceRemoved(QString)),
+             this, SLOT(slotSolidDeviceRemoved(QString)) );
 }
 
 
@@ -161,7 +159,7 @@ K3b::Device::Device* K3b::Device::DeviceManager::deviceByName( const QString& na
 K3b::Device::Device* K3b::Device::DeviceManager::findDevice( const QString& devicename )
 {
     if( devicename.isEmpty() ) {
-        kDebug() << "(K3b::Device::DeviceManager) request for empty device!";
+        qDebug() << "(K3b::Device::DeviceManager) request for empty device!";
         return 0;
     }
 
@@ -260,10 +258,10 @@ K3b::Device::Device* K3b::Device::DeviceManager::checkDevice( const Solid::Devic
 
 void K3b::Device::DeviceManager::printDevices()
 {
-    kDebug() << "Devices:" << endl
+    qDebug() << "Devices:" << endl
              << "------------------------------" << endl;
     Q_FOREACH( Device* dev, d->allDevices ) {
-        kDebug() << "Blockdevice:    " << dev->blockDeviceName() << endl
+        qDebug() << "Blockdevice:    " << dev->blockDeviceName() << endl
                  << "Vendor:         " << dev->vendor() << endl
                  << "Description:    " << dev->description() << endl
                  << "Version:        " << dev->version() << endl
@@ -312,10 +310,10 @@ bool K3b::Device::DeviceManager::readConfig( const KConfigGroup& c )
     for( QList<K3b::Device::Device*>::iterator it = d->allDevices.begin(); it != d->allDevices.end(); ++it ) {
         K3b::Device::Device* dev = *it;
 
-        QString configEntryName = dev->vendor() + " " + dev->description();
+        QString configEntryName = dev->vendor() + ' ' + dev->description();
         QStringList list = c.readEntry( configEntryName, QStringList() );
         if( !list.isEmpty() ) {
-            kDebug() << "(K3b::Device::DeviceManager) found config entry for devicetype: " << configEntryName;
+            qDebug() << "(K3b::Device::DeviceManager) found config entry for devicetype: " << configEntryName;
 
             dev->setMaxReadSpeed( list[0].toInt() );
             if( list.count() > 1 )
@@ -344,7 +342,7 @@ bool K3b::Device::DeviceManager::saveConfig( KConfigGroup c )
     Q_FOREACH( Device* dev, d->allDevices ) {
 
         // save the device type settings
-        QString configEntryName = dev->vendor() + " " + dev->description();
+        QString configEntryName = dev->vendor() + ' ' + dev->description();
         QStringList list;
         list << QString::number(dev->maxReadSpeed())
              << QString::number(dev->maxWriteSpeed());
@@ -359,14 +357,14 @@ bool K3b::Device::DeviceManager::saveConfig( KConfigGroup c )
 K3b::Device::Device* K3b::Device::DeviceManager::addDevice( const Solid::Device& solidDevice )
 {
     if( const Solid::Block* blockDevice = solidDevice.as<Solid::Block>() ) {
-#ifndef __NETBSD__
+#ifndef Q_OS_NETBSD
         if( !findDevice( blockDevice->device() ) )
 #else
-        if( !findDevice( solidDevice.as<Solid::GenericInterface>()->propertyExists("block.netbsd.raw_device") ? solidDevice.as<Solid::GenericInterface>()->property("block.netbsd.raw_device").toString() : blockDevice->device() ) );
+        if( !findDevice( solidDevice.as<Solid::GenericInterface>()->propertyExists("block.netbsd.raw_device") ? solidDevice.as<Solid::GenericInterface>()->property("block.netbsd.raw_device").toString() : blockDevice->device() ) )
 #endif
             return addDevice( new K3b::Device::Device( solidDevice ) );
         else
-            kDebug() << "(K3b::Device::DeviceManager) dev " << blockDevice->device()  << " already found";
+            qDebug() << "(K3b::Device::DeviceManager) dev " << blockDevice->device()  << " already found";
     }
     return 0;
 }
@@ -377,7 +375,7 @@ K3b::Device::Device* K3b::Device::DeviceManager::addDevice( K3b::Device::Device*
     const QString devicename = device->blockDeviceName();
 
     if( !device->init() ) {
-        kDebug() << "Could not initialize device " << devicename;
+        qDebug() << "Could not initialize device " << devicename;
         delete device;
         return 0;
     }
@@ -402,7 +400,7 @@ K3b::Device::Device* K3b::Device::DeviceManager::addDevice( K3b::Device::Device*
 
         if( device->writesCd() ) {
             // default to max write speed
-            kDebug() << "(K3b::Device::DeviceManager) setting current write speed of device "
+            qDebug() << "(K3b::Device::DeviceManager) setting current write speed of device "
                      << device->blockDeviceName()
                      << " to " << device->maxWriteSpeed() << endl;
             device->setCurrentWriteSpeed( device->maxWriteSpeed() );
@@ -439,14 +437,14 @@ void K3b::Device::DeviceManager::removeDevice( const Solid::Device& dev )
 
 void K3b::Device::DeviceManager::slotSolidDeviceAdded( const QString& udi )
 {
-    kDebug() << udi;
+    qDebug() << udi;
     checkDevice( Solid::Device( udi ) );
 }
 
 
 void K3b::Device::DeviceManager::slotSolidDeviceRemoved( const QString& udi )
 {
-    kDebug() << udi;
+    qDebug() << udi;
     Solid::Device solidDev( udi );
     if ( solidDev.isDeviceInterface( Solid::DeviceInterface::OpticalDrive ) ) {
         if ( solidDev.is<Solid::OpticalDrive>() ) {
@@ -455,4 +453,4 @@ void K3b::Device::DeviceManager::slotSolidDeviceRemoved( const QString& udi )
     }
 }
 
-#include "k3bdevicemanager.moc"
+
