@@ -19,11 +19,11 @@
 
 #include "option/k3boptiondialog.h"
 
-#include <KSharedConfig>
-#include <KUrl>
+#include <KConfigCore/KSharedConfig>
 #include <KXmlGuiWindow>
 
-#include <QList>
+#include <QtCore/QList>
+#include <QtCore/QUrl>
 
 namespace K3b {
     class Doc;
@@ -47,7 +47,7 @@ namespace K3b {
         ~MainWindow();
 
         /** opens a file specified by commandline option */
-        Doc* openDocument( const KUrl& url = KUrl() );
+        Doc* openDocument( const QUrl& url = QUrl() );
 
         Device::DeviceManager* deviceManager() const;
         ExternalBinManager* externalBinManager() const;
@@ -72,11 +72,6 @@ namespace K3b {
          *  must be called after construction
          */
         void initView();
-        
-        /**
-         * Reimplemented from QMainWindow, adds "Lock Panels" action
-         */
-        virtual QMenu* createPopupMenu();
 
     public Q_SLOTS:
         K3b::Doc* slotNewAudioDoc();
@@ -90,7 +85,7 @@ namespace K3b {
         void slotClearProject();
 
         void slotWriteImage();
-        void slotWriteImage( const KUrl& url );
+        void slotWriteImage( const QUrl& url );
         void formatMedium( K3b::Device::Device* );
         void slotFormatMedium();
         void mediaCopy( K3b::Device::Device* );
@@ -101,7 +96,6 @@ namespace K3b {
         void slotVideoDvdRip();
         void videoCdRip( K3b::Device::Device* );
         void slotVideoCdRip();
-        void slotK3bSetup();
 
         void showDiskInfo( K3b::Device::Device* );
 
@@ -109,42 +103,33 @@ namespace K3b {
         void slotWarningMessage(const QString&);
 
         void slotConfigureKeys();
-        void slotShowTips();
         void slotCheckSystem();
         void slotManualCheckSystem();
 
-        void addUrls( const KUrl::List& urls );
+        void addUrls( const QList<QUrl>& urls );
 
     Q_SIGNALS:
         void initializationInfo( const QString& );
         void configChanged( KSharedConfig::Ptr c );
 
     protected:
-        /** queryClose is called by KTMainWindow on each closeEvent of a window. Against the
+        /** queryClose is called by KMainWindow on each closeEvent of a window. Against the
          * default implementation (only returns true), this overridden function retrieves all modified documents
          * from the open document list and asks the user to select which files to save before exiting the application.
-         * @see KTMainWindow#queryClose
-         * @see KTMainWindow#closeEvent
+         * @see KMainWindow#queryClose
+         * @see KMainWindow#closeEvent
          */
         virtual bool queryClose();
 
-        /** queryExit is called by KTMainWindow when the last window of the application is going to be closed during the closeEvent().
-         * Against the default implementation that just returns true, this calls saveOptions() to save the settings of the last window's
-         * properties.
-         * @see KTMainWindow#queryExit
-         * @see KTMainWindow#closeEvent
-         */
-        virtual bool queryExit();
-
         /** saves the window properties for each open window during session end to the session config file, including saving the currently
          * opened file by a temporary filename provided by KApplication.
-         * @see KTMainWindow#saveProperties
+         * @see KMainWindow#saveProperties
          */
         virtual void saveProperties(KConfigGroup &_cfg);
 
         /** reads the session config file and restores the application's state including the last opened files and documents by reading the
          * temporary files saved by saveProperties()
-         * @see KTMainWindow#readProperties
+         * @see KMainWindow#readProperties
          */
         virtual void readProperties(const KConfigGroup &_cfg);
 
@@ -158,7 +143,7 @@ namespace K3b {
         /** open a file and load it into the document*/
         void slotFileOpen();
         /** opens a file from the recent files menu */
-        void slotFileOpenRecent(const KUrl& url);
+        void slotFileOpenRecent(const QUrl& url);
         /** save a document */
         void slotFileSave();
         /** save a document by a new filename*/
@@ -181,8 +166,6 @@ namespace K3b {
          */
         void slotViewStatusBar();
 
-        void slotViewLockPanels( bool checked );
-
         /** changes the statusbar contents for the standard label permanently, used to indicate current actions.
          * @param text the text that is displayed in the statusbar
          */
