@@ -20,7 +20,7 @@
 #include "k3bcontentsview.h"
 
 
-class KUrl;
+class QUrl;
 class KActionCollection;
 class KConfigGroup;
 
@@ -36,20 +36,19 @@ public:
     FileView(QWidget *parent=0);
     ~FileView();
 
-    void setUrl( const KUrl &url, bool forward = true );
-    KUrl url();
+    void setUrl( const QUrl &url, bool forward = true );
+    QUrl url();
 
     KActionCollection* actionCollection() const;
 
     void reload();
 
  Q_SIGNALS:
-    void urlEntered( const KUrl& url );
+    void urlEntered( const QUrl& url );
 
 public Q_SLOTS:
     void saveConfig( KConfigGroup grp );
     void readConfig( const KConfigGroup &grp );
-    void setAutoUpdate( bool );
 
 private Q_SLOTS:
     void slotFilterChanged();
