@@ -281,14 +281,15 @@ void K3b::JobProgressDialog::showEvent( QShowEvent* e )
 
 void K3b::JobProgressDialog::closeEvent( QCloseEvent* e )
 {
-    if( m_closeButton->isVisible() ) {
-        QDialog::closeEvent( e );
+    if (m_closeButton->isVisible()) {
+        QDialog::closeEvent(e);
         k3bappcore->k3bMainWindow()->show();
 
-        if( !m_plainCaption.isEmpty() )
-            k3bappcore->k3bMainWindow()->setPlainCaption( m_plainCaption );
-    }
-    else
+        if (!m_plainCaption.isEmpty())
+            k3bappcore->k3bMainWindow()->setPlainCaption(m_plainCaption);
+
+        accept();
+    } else
         e->ignore();
 }
 
@@ -475,8 +476,8 @@ void K3b::JobProgressDialog::setJob( K3b::Job* job )
 
         setWindowTitle( m_job->jobDescription() );
 
-        if( KConfigGroup( KSharedConfig::openConfig(), "General Options" ).readEntry( "Show progress OSD", true ) ) {
-            KIO::getJobTracker()->registerJob( new KJobBridge( *job ) );
+        if (KConfigGroup(KSharedConfig::openConfig(), "General Options").readEntry("Show progress OSD", false)) {
+            KIO::getJobTracker()->registerJob(new KJobBridge(*job));
         }
     }
 }
@@ -540,11 +541,12 @@ void K3b::JobProgressDialog::slotShowDebuggingOutput()
 
 void K3b::JobProgressDialog::slotProgress( int percent )
 {
-    if( percent > d->lastProgress ) {
+    if (percent > d->lastProgress) {
         d->lastProgress = percent;
-        k3bappcore->k3bMainWindow()->setPlainCaption( QString( "(%1%) %2" ).arg(percent).arg(m_plainCaption) );
+        m_plainCaption.replace(QRegularExpression("\\(.+?\\) "), "");
+        k3bappcore->k3bMainWindow()->setPlainCaption(QString("(%1%) %2").arg(percent).arg(m_plainCaption));
 
-        setWindowTitle( QString( "(%1%) %2" ).arg(percent).arg(m_job->jobDescription()) );
+        setWindowTitle(QString("(%1%) %2").arg(percent).arg(m_job->jobDescription()));
     }
 
     if (m_timer.isValid()) {
