@@ -17,18 +17,23 @@
 #include "k3bmetaitemmodel.h"
 // this header is required to return the ItemTypeRole correctly for the
 // places items
-#include "projects/k3bmodeltypes.h"
+#include "k3bdataprojectmodel.h"
 
 #include "k3bcore.h"
 
-#include <KIcon>
-#include <KDebug>
-
-#include <QMimeData>
-#include <QVector>
+#include <QtCore/QDebug>
+#include <QtCore/QMimeData>
+#include <QtCore/QVector>
+#include <QtGui/QIcon>
 
 // IDEA: K3b::MetaItemModel::placeData( int row, int column );
 
+#ifdef __clang__
+#define CLANG_ANALYZER_NORETURN __attribute__((analyzer_noreturn))
+#else
+#define CLANG_ANALYZER_NORETURN
+#endif
+
 namespace {
     class Place;
 
@@ -84,7 +89,7 @@ namespace {
         // a name and icon for the place (used for display)
         // FIXME: better use something like placeData(...)
         QString name;
-        KIcon icon;
+        QIcon icon;
 
         // the row index of this node
         int row;
@@ -131,7 +136,7 @@ namespace {
         // only update children when there is no items in the list
         if ( children.isEmpty() ) {
             // TODO: this is kind of evil since indexes store pointers to the nodes
-            //kDebug() << "resizing children from" << children.size() << "to" << rows;
+            //qDebug() << "resizing children from" << children.size() << "to" << rows;
 
             int rows = model()->rowCount( originalModelIndex );
             for ( int i = 0; i < rows; ++i ) {
@@ -170,6 +175,7 @@ namespace {
         return 0;
     }
 
+    static void K3b_ASSERT(bool test) CLANG_ANALYZER_NORETURN { Q_ASSERT(test); }
 
     Node* Node::createNodeForOriginalIndex( const QModelIndex& index )
     {
@@ -177,10 +183,13 @@ namespace {
             return this;
         }
 
-        Q_ASSERT( index.isValid() );
+        K3b_ASSERT(index.isValid());
 
         // all the node mapping is done on the first col, so make sure we use
         // an index on the first col
+        // 
+        // A valid index belongs to a model, and has non-negative row and column numbers
+        // so index.model() is NOT nullptr if index.isValid()
         QModelIndex firstColIndex = index.model()->index(index.row(), 0, index.parent());
         Node* node = findNodeForOriginalIndex( firstColIndex );
         if ( !node ) {
@@ -424,8 +433,8 @@ QVariant K3b::MetaItemModel::data( const QModelIndex& index, int role ) const
             case Qt::DecorationRole:
                 return node->place()->icon;
 
-            case K3b::ItemTypeRole:
-                return (int) K3b::DirItemType;
+            case DataProjectModel::ItemTypeRole:
+                return (int) DataProjectModel::DirItemType;
 
             default:
                 return QVariant();
@@ -443,7 +452,7 @@ QVariant K3b::MetaItemModel::data( const QModelIndex& index, int role ) const
 
 QModelIndex K3b::MetaItemModel::index( int row, int column, const QModelIndex& parent ) const
 {
-    //kDebug() << row << column << parent;
+    //qDebug() << row << column << parent;
 
     if ( row < 0 || column < 0 ) {
         return QModelIndex();
@@ -474,7 +483,7 @@ QModelIndex K3b::MetaItemModel::index( int row, int column, const QModelIndex& p
 
 QModelIndex K3b::MetaItemModel::parent( const QModelIndex& index ) const
 {
-    //kDebug() << "Parent of" << index;
+    //qDebug() << "Parent of" << index;
     Node* node = d->nodeForIndex( index );
 
     if ( !index.isValid() || !node || node->isPlace() )
@@ -518,7 +527,7 @@ Qt::ItemFlags K3b::MetaItemModel::flags( const QModelIndex& index ) const
 
 bool K3b::MetaItemModel::hasChildren( const QModelIndex& parent ) const
 {
-//    kDebug() << parent;
+//    qDebug() << parent;
 
     if ( parent.isValid() ) {
         Node* parentNode = d->nodeForIndex( parent );
@@ -538,7 +547,7 @@ bool K3b::MetaItemModel::hasChildren( const QModelIndex& parent ) const
 
 bool K3b::MetaItemModel::canFetchMore( const QModelIndex& parent ) const
 {
-//    kDebug() << parent;
+//    qDebug() << parent;
 
     if ( parent.isValid() ) {
         Node* parentNode = d->nodeForIndex( parent );
@@ -552,7 +561,7 @@ bool K3b::MetaItemModel::canFetchMore( const QModelIndex& parent ) const
 
 void K3b::MetaItemModel::fetchMore( const QModelIndex& parent )
 {
-//    kDebug() << parent;
+//    qDebug() << parent;
 
     if ( parent.isValid() ) {
         Node* parentNode = d->nodeForIndex( parent );
@@ -563,7 +572,7 @@ void K3b::MetaItemModel::fetchMore( const QModelIndex& parent )
 
 int K3b::MetaItemModel::rowCount( const QModelIndex& parent ) const
 {
-//    kDebug() << parent;
+//    qDebug() << parent;
     if ( parent.column() > 0 )
         return 0;
 
@@ -590,7 +599,7 @@ int K3b::MetaItemModel::rowCount( const QModelIndex& parent ) const
 
 bool K3b::MetaItemModel::setData( const QModelIndex& index, const QVariant& value, int role )
 {
-//    kDebug() << index;
+//    qDebug() << index;
 
     if ( index.isValid() ) {
         Node* node = d->nodeForIndex( index );
@@ -622,7 +631,7 @@ QStringList K3b::MetaItemModel::mimeTypes() const
 
 bool K3b::MetaItemModel::dropMimeData( const QMimeData* data, Qt::DropAction action, int row, int column, const QModelIndex& parent )
 {
-//    kDebug();
+//    qDebug();
 
     if ( parent.isValid() ) {
         Node* parentNode = d->nodeForIndex( parent );
@@ -684,7 +693,7 @@ QMimeData* K3b::MetaItemModel::mimeData( const QModelIndexList& indexes ) const
               it != indexes.constEnd(); ++it ) {
             QModelIndex sourceIndex = mapToSubModel( *it );
             if ( !origIndexes.isEmpty() && sourceIndex.model() != origIndexes.first().model() ) {
-                kDebug() << "cannot handle indexes from different submodels yet.";
+                qDebug() << "cannot handle indexes from different submodels yet.";
                 return 0;
             }
             origIndexes.append( sourceIndex );
@@ -696,6 +705,17 @@ QMimeData* K3b::MetaItemModel::mimeData( const QModelIndexList& indexes ) const
 }
 
 
+Qt::DropActions K3b::MetaItemModel::supportedDragActions() const
+{
+    Qt::DropActions a = Qt::IgnoreAction;
+
+    for ( int i = 0; i < d->places.count(); ++i ) {
+        a |= d->places[i].model()->supportedDragActions();
+    }
+    return a;
+}
+
+
 Qt::DropActions K3b::MetaItemModel::supportedDropActions() const
 {
     Qt::DropActions a = Qt::IgnoreAction;
@@ -707,7 +727,7 @@ Qt::DropActions K3b::MetaItemModel::supportedDropActions() const
 }
 
 
-void K3b::MetaItemModel::addSubModel( const QString& name, const KIcon& icon, QAbstractItemModel* model, bool flat )
+void K3b::MetaItemModel::addSubModel( const QString& name, const QIcon& icon, QAbstractItemModel* model, bool flat )
 {
     int first = d->places.count(), last = d->places.count();
 
@@ -730,23 +750,26 @@ void K3b::MetaItemModel::addSubModel( const QString& name, const KIcon& icon, QA
 
     d->updatePlaceRows();
 
-    connect( place.model(), SIGNAL( modelReset() ),
-             this, SLOT( slotReset() ) );
+    connect( place.model(), SIGNAL(modelAboutToBeReset()),
+             this, SLOT(slotAboutToBeReset()) );
 
-    connect( place.model(), SIGNAL( rowsAboutToBeInserted( const QModelIndex&, int, int ) ),
-             this, SLOT( slotRowsAboutToBeInserted( const QModelIndex&, int, int ) ) );
+    connect( place.model(), SIGNAL(modelReset()),
+             this, SLOT(slotReset()) );
 
-    connect( place.model(), SIGNAL( rowsInserted( const QModelIndex&, int, int ) ),
-             this, SLOT( slotRowsInserted( const QModelIndex&, int, int ) ) );
+    connect( place.model(), SIGNAL(rowsAboutToBeInserted(QModelIndex,int,int)),
+             this, SLOT(slotRowsAboutToBeInserted(QModelIndex,int,int)) );
 
-    connect( place.model(), SIGNAL( rowsAboutToBeRemoved( const QModelIndex&, int, int ) ),
-             this, SLOT( slotRowsAboutToBeRemoved( const QModelIndex&, int, int ) ) );
+    connect( place.model(), SIGNAL(rowsInserted(QModelIndex,int,int)),
+             this, SLOT(slotRowsInserted(QModelIndex,int,int)) );
 
-    connect( place.model(), SIGNAL( rowsRemoved( const QModelIndex&, int, int ) ),
-             this, SLOT( slotRowsRemoved( const QModelIndex&, int, int ) ) );
+    connect( place.model(), SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),
+             this, SLOT(slotRowsAboutToBeRemoved(QModelIndex,int,int)) );
 
-    connect( place.model(), SIGNAL( dataChanged( const QModelIndex&, const QModelIndex& ) ),
-             this, SLOT( slotDataChanged( const QModelIndex&, const QModelIndex& ) ) );
+    connect( place.model(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
+             this, SLOT(slotRowsRemoved(QModelIndex,int,int)) );
+
+    connect( place.model(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
+             this, SLOT(slotDataChanged(QModelIndex,QModelIndex)) );
 
     if ( first <= last )
         endInsertRows();
@@ -866,7 +889,7 @@ void K3b::MetaItemModel::slotRowsInserted( const QModelIndex& parent, int start,
 
 void K3b::MetaItemModel::slotRowsAboutToBeRemoved( const QModelIndex& parent, int start, int end )
 {
-    //kDebug();
+    //qDebug();
 
     Place* place = d->placeForModel( qobject_cast<QAbstractItemModel*>( sender() ) );
     Q_ASSERT( place != 0 );
@@ -926,7 +949,7 @@ void K3b::MetaItemModel::slotRowsRemoved( const QModelIndex&, int, int )
 
 void K3b::MetaItemModel::slotDataChanged( const QModelIndex& topLeft, const QModelIndex& bottomRight )
 {
-    //kDebug();
+    //qDebug();
 
     Q_ASSERT( topLeft.isValid() );
     Q_ASSERT( bottomRight.isValid() );
@@ -935,6 +958,12 @@ void K3b::MetaItemModel::slotDataChanged( const QModelIndex& topLeft, const QMod
 }
 
 
+void K3b::MetaItemModel::slotAboutToBeReset()
+{
+    beginResetModel();
+}
+
+
 void K3b::MetaItemModel::slotReset()
 {
     // clean out any cached nodes
@@ -943,7 +972,7 @@ void K3b::MetaItemModel::slotReset()
     }
     d->updatePlaceRows();
 
-    reset();
+    endResetModel();
 }
 
-#include "k3bmetaitemmodel.moc"
+
