@@ -22,11 +22,12 @@
 #include "k3baudiotrack.h"
 #include "k3baudiotrackaddingdialog.h"
 
-#include <KLocale>
-#include <KIcon>
+#include <KCoreAddons/KUrlMimeData>
+#include <KI18n/KLocalizedString>
 
-#include <QApplication>
-#include <QMimeData>
+#include <QtCore/QMimeData>
+#include <QtGui/QIcon>
+#include <QtWidgets/QApplication>
 
 
 // we have K3b::AudioTracks in the first level and K3b::AudioDataSources in the second level
@@ -41,49 +42,37 @@ public:
 
     K3b::AudioDoc* project;
 
-    void _k_docChanged();
-    void _k_aboutToAddTrack( int position );
-    void _k_trackAdded( K3b::AudioTrack* );
-    void _k_aboutToRemoveTrack( K3b::AudioTrack* );
+    void _k_trackAboutToBeAdded( int position );
+    void _k_trackAdded();
+    void _k_trackAboutToBeRemoved( int position );
     void _k_trackRemoved();
-    void _k_aboutToAddSource( K3b::AudioTrack*, int );
-    void _k_sourceAdded( K3b::AudioTrack*, int );
-    void _k_aboutToRemoveSource( K3b::AudioTrack*, int );
-    void _k_sourceRemoved( K3b::AudioTrack* );
+    void _k_sourceAboutToBeAdded( K3b::AudioTrack* parent, int position );
+    void _k_sourceAdded();
+    void _k_sourceAboutToBeRemoved( K3b::AudioTrack* parent, int position );
+    void _k_sourceRemoved();
 
 private:
     AudioProjectModel* q;
 };
 
 
-void K3b::AudioProjectModel::Private::_k_docChanged()
+void K3b::AudioProjectModel::Private::_k_trackAboutToBeAdded( int position )
 {
-    q->reset();
-}
-
-
-void K3b::AudioProjectModel::Private::_k_aboutToAddTrack( int position )
-{
-    if (position >= 0) {
+    if( position >= 0 ) {
         q->beginInsertRows( QModelIndex(), position, position );
     }
 }
 
 
-void K3b::AudioProjectModel::Private::_k_trackAdded( K3b::AudioTrack* track )
+void K3b::AudioProjectModel::Private::_k_trackAdded()
 {
-    int index = track->trackNumber() - 1;
-    if (index >= 0) {
-        // do nothing
-        q->endInsertRows();
-    }
+    q->endInsertRows();
 }
 
 
-void K3b::AudioProjectModel::Private::_k_aboutToRemoveTrack( K3b::AudioTrack* track )
+void K3b::AudioProjectModel::Private::_k_trackAboutToBeRemoved( int position )
 {
-    int index = track->trackNumber() - 1;
-    q->beginRemoveRows( QModelIndex(), index, index );
+    q->beginRemoveRows( QModelIndex(), position, position );
 }
 
 
@@ -93,31 +82,26 @@ void K3b::AudioProjectModel::Private::_k_trackRemoved()
 }
 
 
-void K3b::AudioProjectModel::Private::_k_aboutToAddSource( K3b::AudioTrack* track, int position )
+void K3b::AudioProjectModel::Private::_k_sourceAboutToBeAdded( K3b::AudioTrack* parent, int position )
 {
-    QModelIndex parent = q->indexForTrack( track );
-    q->beginInsertRows( parent, position, position );
+    q->beginInsertRows( q->indexForTrack( parent ), position, position );
 }
 
 
-void K3b::AudioProjectModel::Private::_k_sourceAdded( K3b::AudioTrack*, int )
+void K3b::AudioProjectModel::Private::_k_sourceAdded()
 {
-    // do nothing
     q->endInsertRows();
 }
 
 
-void K3b::AudioProjectModel::Private::_k_aboutToRemoveSource( K3b::AudioTrack* track, int position )
+void K3b::AudioProjectModel::Private::_k_sourceAboutToBeRemoved( K3b::AudioTrack* parent, int position )
 {
-    QModelIndex parent = q->indexForTrack( track );
-    q->beginRemoveRows( parent, position, position );
+    q->beginRemoveRows( q->indexForTrack( parent ), position, position );
 }
 
 
-void K3b::AudioProjectModel::Private::_k_sourceRemoved( K3b::AudioTrack* track )
+void K3b::AudioProjectModel::Private::_k_sourceRemoved()
 {
-    Q_UNUSED( track );
-
     q->endRemoveRows();
 }
 
@@ -126,24 +110,23 @@ K3b::AudioProjectModel::AudioProjectModel( K3b::AudioDoc* doc, QObject* parent )
     : QAbstractItemModel( parent ),
       d( new Private( doc, this ) )
 {
-    setSupportedDragActions( Qt::MoveAction );
-    
-    connect( doc, SIGNAL( changed() ), this, SLOT( _k_docChanged() ) );
-    connect( doc, SIGNAL( aboutToRemoveTrack( K3b::AudioTrack* ) ),
-             this, SLOT( _k_aboutToRemoveTrack( K3b::AudioTrack* ) ) );
-    connect( doc, SIGNAL( aboutToAddTrack( int ) ),
-             this, SLOT( _k_aboutToAddTrack( int ) ) );
-    connect( doc, SIGNAL( trackAdded( K3b::AudioTrack* ) ),
-             this, SLOT( _k_trackAdded( K3b::AudioTrack* ) ) );
+    connect( doc, SIGNAL(trackAboutToBeRemoved(int)),
+             this, SLOT(_k_trackAboutToBeRemoved(int)), Qt::DirectConnection );
+    connect( doc, SIGNAL(trackRemoved(int)),
+             this, SLOT(_k_trackRemoved()), Qt::DirectConnection );
+    connect( doc, SIGNAL(trackAboutToBeAdded(int)),
+             this, SLOT(_k_trackAboutToBeAdded(int)), Qt::DirectConnection );
+    connect( doc, SIGNAL(trackAdded(int)),
+             this, SLOT(_k_trackAdded()), Qt::DirectConnection );
 
-    connect( doc, SIGNAL( aboutToAddSource( K3b::AudioTrack*, int ) ),
-             this, SLOT( _k_aboutToAddSource( K3b::AudioTrack*, int ) ) );
-    connect( doc, SIGNAL( sourceAdded( K3b::AudioTrack*, int ) ),
-             this, SLOT( _k_sourceAdded( K3b::AudioTrack*, int ) ) );
-    connect( doc, SIGNAL( aboutToRemoveSource( K3b::AudioTrack*, int ) ),
-             this, SLOT( _k_aboutToRemoveSource( K3b::AudioTrack*, int ) ) );
-    connect( doc, SIGNAL( sourceRemoved( K3b::AudioTrack* ) ),
-             this, SLOT( _k_sourceRemoved( K3b::AudioTrack* ) ) );
+    connect( doc, SIGNAL(sourceAboutToBeAdded(K3b::AudioTrack*,int)),
+             this, SLOT(_k_sourceAboutToBeAdded(K3b::AudioTrack*,int)), Qt::DirectConnection );
+    connect( doc, SIGNAL(sourceAdded(K3b::AudioTrack*,int)),
+             this, SLOT(_k_sourceAdded()), Qt::DirectConnection );
+    connect( doc, SIGNAL(sourceAboutToBeRemoved(K3b::AudioTrack*,int)),
+             this, SLOT(_k_sourceAboutToBeRemoved(K3b::AudioTrack*,int)), Qt::DirectConnection );
+    connect( doc, SIGNAL(sourceRemoved(K3b::AudioTrack*,int)),
+             this, SLOT(_k_sourceRemoved()), Qt::DirectConnection );
 }
 
 
@@ -171,9 +154,9 @@ K3b::AudioTrack* K3b::AudioProjectModel::trackForIndex( const QModelIndex& index
 }
 
 
-QModelIndex K3b::AudioProjectModel::indexForTrack( K3b::AudioTrack* track ) const
+QModelIndex K3b::AudioProjectModel::indexForTrack( const K3b::AudioTrack* track ) const
 {
-    return createIndex( track->trackNumber()-1, 0, track );
+    return createIndex( track->trackNumber()-1, 0, const_cast<AudioTrack*>( track ) );
 }
 
 
@@ -354,7 +337,7 @@ QModelIndex K3b::AudioProjectModel::index( int row, int column, const QModelInde
     if ( !hasIndex( row, column, parent ) ) {
         return QModelIndex();
     }
-    
+
     // source
     else if ( parent.isValid() && parent.column() == 0 ) {
         if ( K3b::AudioTrack* track = trackForIndex( parent ) ) {
@@ -406,15 +389,19 @@ int K3b::AudioProjectModel::rowCount( const QModelIndex& parent ) const
 
 bool K3b::AudioProjectModel::setData( const QModelIndex& index, const QVariant& value, int role )
 {
-    if ( index.isValid() ) {
-        if ( K3b::AudioTrack* track = trackForIndex( index ) ) {
-            if ( role == Qt::EditRole ) {
-                switch( index.column() ) {
-                case ArtistColumn:
+    if ( K3b::AudioTrack* track = trackForIndex( index ) ) {
+        if ( role == Qt::EditRole ) {
+            if ( index.column() == ArtistColumn ) {
+                if( value.toString() != track->artist() ) {
                     track->setArtist( value.toString() );
+                    emit dataChanged( index, index );
                     return true;
-                case TitleColumn:
+                }
+            }
+            else if ( index.column() == TitleColumn ) {
+                if( value.toString() != track->artist() ) {
                     track->setTitle( value.toString() );
+                    emit dataChanged( index, index );
                     return true;
                 }
             }
@@ -430,15 +417,15 @@ QMimeData* K3b::AudioProjectModel::mimeData( const QModelIndexList& indexes ) co
 
     QSet<K3b::AudioTrack*> tracks;
     QSet<K3b::AudioDataSource*> sources;
-    KUrl::List urls;
+    QList<QUrl> urls;
     foreach( const QModelIndex& index, indexes ) {
         if ( K3b::AudioTrack* track = trackForIndex( index ) ) {
             tracks << track;
             K3b::AudioDataSource* source = track->firstSource();
             while ( source ) {
                 if ( K3b::AudioFile* file = dynamic_cast<K3b::AudioFile*>( source ) ) {
-                    if ( !urls.contains( KUrl( file->filename() ) ) ) {
-                        urls.append( KUrl( file->filename() ) );
+                    if ( !urls.contains( QUrl::fromLocalFile( file->filename() ) ) ) {
+                        urls.append( QUrl::fromLocalFile( file->filename() ) );
                     }
                 }
                 source = source->next();
@@ -447,13 +434,13 @@ QMimeData* K3b::AudioProjectModel::mimeData( const QModelIndexList& indexes ) co
         else if ( K3b::AudioDataSource* source = sourceForIndex( index ) ) {
             sources << source;
             if ( K3b::AudioFile* file = dynamic_cast<K3b::AudioFile*>( source ) ) {
-                if ( !urls.contains( KUrl( file->filename() ) ) ) {
-                    urls.append( KUrl( file->filename() ) );
+                if ( !urls.contains( QUrl::fromLocalFile( file->filename() ) ) ) {
+                    urls.append( QUrl::fromLocalFile( file->filename() ) );
                 }
             }
         }
     }
-    urls.populateMimeData( mime );
+    mime->setUrls(urls);
 
     // the easy road: encode the pointers
     if ( !tracks.isEmpty() ) {
@@ -477,6 +464,12 @@ QMimeData* K3b::AudioProjectModel::mimeData( const QModelIndexList& indexes ) co
 }
 
 
+Qt::DropActions K3b::AudioProjectModel::supportedDragActions() const
+{
+    return Qt::MoveAction;
+}
+
+
 Qt::DropActions K3b::AudioProjectModel::supportedDropActions() const
 {
     return Qt::CopyAction|Qt::MoveAction;
@@ -485,7 +478,7 @@ Qt::DropActions K3b::AudioProjectModel::supportedDropActions() const
 
 QStringList K3b::AudioProjectModel::mimeTypes() const
 {
-    QStringList s = KUrl::List::mimeDataTypes();
+    QStringList s = KUrlMimeData::mimeDataTypes();
     s += AudioCdTrackDrag::mimeDataTypes();
     s += QString::fromLatin1( "application/x-k3baudiotrack" );
     s += QString::fromLatin1( "application/x-k3baudiodatasource" );
@@ -559,7 +552,7 @@ bool K3b::AudioProjectModel::dropMimeData( const QMimeData* data, Qt::DropAction
     //
     QList<K3b::AudioTrack*> tracks;
     QList<K3b::AudioDataSource*> sources;
-    KUrl::List urls;
+    QList<QUrl> urls;
     if ( data->hasFormat( "application/x-k3baudiotrack" ) ||
          data->hasFormat( "application/x-k3baudiodatasource" )) {
 
@@ -639,7 +632,7 @@ bool K3b::AudioProjectModel::dropMimeData( const QMimeData* data, Qt::DropAction
 
                 // special case: the source we remove from the track is the last and the track
                 // will be deleted.
-                if( !copyItems && dropTrackAfter == source->track() && dropTrackAfter->numberSources() == 1 )
+                if( !copyItems && dropTrackAfter == source->track() && dropTrackAfter && dropTrackAfter->numberSources() == 1 )
                     dropTrackAfter = dropTrackAfter->prev();
 
                 if( copyItems )
@@ -665,13 +658,13 @@ bool K3b::AudioProjectModel::dropMimeData( const QMimeData* data, Qt::DropAction
     // handle tracks from the audio cd view
     //
     else if ( AudioCdTrackDrag::canDecode( data ) ) {
-        kDebug() << "audiocdtrack dropped.";
+        qDebug() << "audiocdtrack dropped.";
 
         AudioCdTrackDrag drag = AudioCdTrackDrag::fromMimeData( data );
 
         // for now we just create one source
         foreach( int trackNumber, drag.trackNumbers() ) {
-            kDebug() << trackNumber << "dropped";
+            qDebug() << trackNumber << "dropped";
             AudioCdTrackSource* source = new AudioCdTrackSource( drag.toc(),
                                                                  trackNumber,
                                                                  drag.cddbEntry().track( trackNumber-1 ).get( KCDDB::Artist ).toString(),
@@ -702,9 +695,9 @@ bool K3b::AudioProjectModel::dropMimeData( const QMimeData* data, Qt::DropAction
     //
     // add new tracks
     //
-    else if ( KUrl::List::canDecode( data ) ) {
-        kDebug() << "url list drop";
-        KUrl::List urls = KUrl::List::fromMimeData( data );
+    else if ( data->hasUrls() ) {
+        qDebug() << "url list drop";
+        QList<QUrl> urls = KUrlMimeData::urlsFromMimeData( data );
         K3b::AudioTrackAddingDialog::addUrls( urls, d->project, dropTrackAfter, dropTrackParent, dropSourceAfter, qApp->activeWindow() );
         return true;
     }
@@ -713,4 +706,4 @@ bool K3b::AudioProjectModel::dropMimeData( const QMimeData* data, Qt::DropAction
 }
 
 
-#include "k3baudioprojectmodel.moc"
+#include "moc_k3baudioprojectmodel.cpp"
