@@ -32,31 +32,25 @@
 #include "k3bexternalbinmanager.h"
 #include "k3bversion.h"
 #include "k3bcore.h"
-//#include "k3baudiotrackplayer.h"
 #include "k3bintmapcombobox.h"
 
-#include <qtabwidget.h>
-#include <qcheckbox.h>
-#include <q3groupbox.h>
-#include <qlabel.h>
-#include <qlineedit.h>
-#include <qpushbutton.h>
-#include <qtoolbutton.h>
-#include <qlayout.h>
-#include <qvariant.h>
-#include <qtooltip.h>
+#include <KConfigCore/KConfig>
+#include <KI18n/KLocalizedString>
+#include <KWidgetsAddons/KMessageBox>
 
-#include <q3buttongroup.h>
-#include <qradiobutton.h>
-//Added by qt3to4:
-#include <QGridLayout>
-
-#include <klocale.h>
-#include <kconfig.h>
-#include <kapplication.h>
-#include <kdebug.h>
-#include <kmessagebox.h>
-#include <kvbox.h>
+#include <QtCore/QDebug>
+#include <QtCore/QVariant>
+#include <QtWidgets/QCheckBox>
+#include <QtWidgets/QGridLayout>
+#include <QtWidgets/QGroupBox>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLayout>
+#include <QtWidgets/QLineEdit>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QRadioButton>
+#include <QtWidgets/QTabWidget>
+#include <QtWidgets/QToolButton>
+#include <QtWidgets/QToolTip>
 
 
 K3b::MixedBurnDialog::MixedBurnDialog( K3b::MixedDoc* doc, QWidget *parent )
@@ -95,13 +89,13 @@ void K3b::MixedBurnDialog::setupSettingsPage()
 {
     QWidget* w = new QWidget( this );
 
-    Q3GroupBox* groupDataMode = new Q3GroupBox( 1, Qt::Vertical, i18n("Datatrack Mode"), w );
+    QGroupBox* groupDataMode = new QGroupBox( i18n("Datatrack Mode"), w );
     m_dataModeWidget = new K3b::DataModeWidget( groupDataMode );
 
-    Q3GroupBox* groupNormalize = new Q3GroupBox( 1, Qt::Vertical, i18n("Misc"), w );
+    QGroupBox* groupNormalize = new QGroupBox( i18n("Misc"), w );
     m_checkNormalize = K3b::StdGuiItems::normalizeCheckBox( groupNormalize );
 
-    Q3GroupBox* groupMixedType = new Q3GroupBox( 1, Qt::Vertical, i18n("Mixed Mode Type"), w );
+    QGroupBox* groupMixedType = new QGroupBox( i18n("Mixed Mode Type"), w );
     m_comboMixedModeType = new K3b::IntMapComboBox( groupMixedType );
 
     m_comboMixedModeType->insertItem( K3b::MixedDoc::DATA_SECOND_SESSION,
@@ -331,5 +325,5 @@ void K3b::MixedBurnDialog::slotCacheImageToggled( bool on )
 }
 
 
-#include "k3bmixedburndialog.moc"
+
 
