@@ -30,38 +30,36 @@
 #include "k3baudioencoder.h"
 #include "k3bmediacache.h"
 
-#include <KApplication>
-#include <KComboBox>
-#include <KConfig>
-#include <KDebug>
-#include <KFileDialog>
-#include <kio/global.h>
-#include <KLocale>
-#include <KMessageBox>
-#include <KUrlLabel>
-#include <KUrlRequester>
+#include <KCompletion/KComboBox>
+#include <KConfigCore/KConfig>
+#include <KI18n/KLocalizedString>
+#include <KIOCore/KIO/Global>
+#include <KIOWidgets/KUrlRequester>
+#include <KWidgetsAddons/KMessageBox>
+#include <KWidgetsAddons/KUrlLabel>
 
-#include <QCheckBox>
-#include <QDir>
-#include <QFont>
-#include <QGridLayout>
-#include <QGroupBox>
-#include <QHash>
-#include <QHeaderView>
-#include <QLabel>
-#include <QLayout>
-#include <QList>
-#include <QMessageBox>
-#include <QPair>
-#include <QPushButton>
-#include <QTabWidget>
-#include <QToolButton>
-#include <QToolTip>
-#include <QTreeWidget>
-#include <QSpinBox>
-#include <QStringList>
-#include <QValidator>
-#include <QVariant>
+#include <QtCore/QDebug>
+#include <QtCore/QDir>
+#include <QtCore/QHash>
+#include <QtCore/QList>
+#include <QtCore/QPair>
+#include <QtCore/QStringList>
+#include <QtCore/QVariant>
+#include <QtGui/QFont>
+#include <QtGui/QValidator>
+#include <QtWidgets/QGridLayout>
+#include <QtWidgets/QGroupBox>
+#include <QtWidgets/QCheckBox>
+#include <QtWidgets/QHeaderView>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLayout>
+#include <QtWidgets/QMessageBox>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QTabWidget>
+#include <QtWidgets/QToolButton>
+#include <QtWidgets/QToolTip>
+#include <QtWidgets/QTreeWidget>
+#include <QtWidgets/QSpinBox>
 
 
 
@@ -136,14 +134,14 @@ void K3b::AudioRippingDialog::setupGui()
 {
     QWidget *frame = mainWidget();
     QGridLayout* Form1Layout = new QGridLayout( frame );
-    Form1Layout->setMargin( 0 );
-    
+    Form1Layout->setContentsMargins( 0, 0, 0, 0 );
+
     QTreeWidgetItem* header = new QTreeWidgetItem;
     header->setText( 0, i18n( "Filename") );
     header->setText( 1, i18n( "Length") );
     header->setText( 2, i18n( "File Size") );
     header->setText( 3, i18n( "Type") );
-    
+
     d->viewTracks = new QTreeWidget( frame );
     d->viewTracks->setSortingEnabled( false );
     d->viewTracks->setAllColumnsShowFocus( true );
@@ -152,10 +150,10 @@ void K3b::AudioRippingDialog::setupGui()
     d->viewTracks->setSelectionMode( QAbstractItemView::NoSelection );
     d->viewTracks->setFocusPolicy( Qt::NoFocus );
     d->viewTracks->header()->setStretchLastSection( false );
-    d->viewTracks->header()->setResizeMode( 0, QHeaderView::Stretch );
-    d->viewTracks->header()->setResizeMode( 1, QHeaderView::ResizeToContents );
-    d->viewTracks->header()->setResizeMode( 2, QHeaderView::ResizeToContents );
-    d->viewTracks->header()->setResizeMode( 3, QHeaderView::ResizeToContents );
+    d->viewTracks->header()->setSectionResizeMode( 0, QHeaderView::Stretch );
+    d->viewTracks->header()->setSectionResizeMode( 1, QHeaderView::ResizeToContents );
+    d->viewTracks->header()->setSectionResizeMode( 2, QHeaderView::ResizeToContents );
+    d->viewTracks->header()->setSectionResizeMode( 3, QHeaderView::ResizeToContents );
 
     QTabWidget* mainTab = new QTabWidget( frame );
 
@@ -263,7 +261,7 @@ void K3b::AudioRippingDialog::slotStartClicked()
         if( KMessageBox::questionYesNoList( this,
                                             i18n("Do you want to overwrite these files?"),
                                             filesToOverwrite,
-                                            i18n("Files Exist"), KGuiItem(i18n("Overwrite")), KStandardGuiItem::cancel() ) == KMessageBox::No )
+                                            i18n("Files Exist"), KStandardGuiItem::overwrite(), KStandardGuiItem::cancel() ) == KMessageBox::No )
             return;
 
 
@@ -288,7 +286,7 @@ void K3b::AudioRippingDialog::slotStartClicked()
     K3b::AudioRipJob* job = new K3b::AudioRipJob( &ripDialog, this );
     job->setDevice( m_medium.device() );
     job->setCddbEntry( m_cddbEntry );
-    job->setTracksToRip( tracksToRip );
+    job->setTrackList( tracksToRip );
     job->setParanoiaMode( m_comboParanoiaMode->currentText().toInt() );
     job->setMaxRetries( m_spinRetries->value() );
     job->setNeverSkip( !m_checkIgnoreReadErrors->isChecked() );
@@ -303,7 +301,7 @@ void K3b::AudioRippingDialog::slotStartClicked()
     hide();
     ripDialog.startJob(job);
 
-    kDebug() << "(K3b::AudioRippingDialog) deleting ripjob.";
+    qDebug() << "(K3b::AudioRippingDialog) deleting ripjob.";
     delete job;
 
     close();
@@ -403,7 +401,7 @@ void K3b::AudioRippingDialog::refresh()
                                                          m_patternWidget->replaceBlanks(),
                                                          m_patternWidget->blankReplaceString() );
             if ( filename.isEmpty() ){
-                filename = i18n("Track%1", QString::number( trackIndex+1 ).rightJustified( 2, '0' ) ) + "." + extension;
+                filename = i18n("Track%1", QString::number( trackIndex+1 ).rightJustified( 2, '0' ) ) + '.' + extension;
             }
             filename = d->fsInfo.fixupPath( filename );
 
@@ -426,7 +424,7 @@ void K3b::AudioRippingDialog::refresh()
 
         d->addTrack( filename, "-", "-", i18n("Playlist") );
 
-        d->playlistFilename = d->fsInfo.fixupPath( baseDir + "/" + filename );
+        d->playlistFilename = d->fsInfo.fixupPath( baseDir + '/' + filename );
     }
 
     if( overallSize > 0 )
@@ -467,4 +465,4 @@ void K3b::AudioRippingDialog::saveSettings( KConfigGroup c )
     m_patternWidget->saveConfig( c );
 }
 
-#include "k3baudiorippingdialog.moc"
+
