@@ -13,36 +13,31 @@
 * See the file "COPYING" for the exact licensing terms.
 */
 
-// k3b includes
 #include "k3bvideocdrippingdialog.h"
 #include "k3bvideocdrip.h"
-
 #include "k3bjobprogressdialog.h"
 #include "k3bcore.h"
 #include "k3bglobals.h"
 #include "k3bstdguiitems.h"
 
-// kde include
-#include <KApplication>
-#include <KColorScheme>
-#include <KConfig>
-#include <KDebug>
-#include <KLocale>
-#include <KMessageBox>
-#include <KStandardDirs>
-#include <KUrlRequester>
+#include <KConfigWidgets/KColorScheme>
+#include <KConfigCore/KConfig>
+#include <KI18n/KLocalizedString>
+#include <KIOWidgets/KUrlRequester>
+#include <KWidgetsAddons/KMessageBox>
 
-// qt includes
-#include <QCheckBox>
-#include <QDir>
-#include <QFileInfo>
-#include <QGridLayout>
-#include <QLabel>
-#include <QLayout>
-#include <QStringList>
-#include <QTimer>
-#include <QToolTip>
-#include <KVBox>
+#include <QtCore/QDebug>
+#include <QtCore/QDir>
+#include <QtCore/QFileInfo>
+#include <QtCore/QStringList>
+#include <QtCore/QTimer>
+#include <QtWidgets/QGridLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QLayout>
+#include <QtWidgets/QCheckBox>
+#include <QtWidgets/QGroupBox>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QToolTip>
 
 
 K3b::VideoCdRippingDialog::VideoCdRippingDialog( K3b::VideoCdRippingOptions* options, QWidget* parent )
@@ -68,7 +63,7 @@ void K3b::VideoCdRippingDialog::setupGui()
 {
     QWidget * frame = mainWidget();
     QGridLayout* MainLayout = new QGridLayout( frame );
-    MainLayout->setMargin( 0 );
+    MainLayout->setContentsMargins( 0, 0, 0, 0 );
 
     // ---------------------------------------------------- Directory group ---
     QGroupBox* groupDirectory = new QGroupBox( i18n( "Destination Folder" ), frame );
@@ -82,21 +77,22 @@ void K3b::VideoCdRippingDialog::setupGui()
 
     rippathLabel->setBuddy( m_editDirectory );
 
-    KHBox* freeSpaceBox = new KHBox( groupDirectory );
-    ( void ) new QLabel( i18n( "Free space in folder:" ), freeSpaceBox );
-    m_labelFreeSpace = new QLabel( "                       ", freeSpaceBox );
+    QHBoxLayout* freeSpaceBox = new QHBoxLayout;
+    freeSpaceBox->addWidget( new QLabel( i18n( "Free space in folder:" ), groupDirectory ) );
+    m_labelFreeSpace = new QLabel( "                       ", groupDirectory );
     m_labelFreeSpace->setAlignment( Qt::AlignVCenter | Qt::AlignRight );
+    freeSpaceBox->addWidget( m_labelFreeSpace );
 
-    KHBox* necessarySizeBox = new KHBox( groupDirectory );
-    ( void ) new QLabel( i18n( "Necessary storage size:" ), necessarySizeBox );
-    m_labelNecessarySize = new QLabel( "                        ", necessarySizeBox );
+    QHBoxLayout* necessarySizeBox = new QHBoxLayout;
+    necessarySizeBox->addWidget( new QLabel( i18n( "Necessary storage size:" ), groupDirectory ) );
+    m_labelNecessarySize = new QLabel( "                        ", groupDirectory );
     m_labelNecessarySize->setAlignment( Qt::AlignVCenter | Qt::AlignRight );
-
+    necessarySizeBox->addWidget( m_labelNecessarySize );
 
     groupDirectoryLayout->addWidget( rippathLabel, 0, 0 );
     groupDirectoryLayout->addWidget( m_editDirectory, 0, 1 );
-    groupDirectoryLayout->addWidget( freeSpaceBox, 1, 1 );
-    groupDirectoryLayout->addWidget( necessarySizeBox, 2, 1 );
+    groupDirectoryLayout->addLayout( freeSpaceBox, 1, 1 );
+    groupDirectoryLayout->addLayout( necessarySizeBox, 2, 1 );
 
     // ---------------------------------------------------- Options group ---
     QGroupBox* groupOptions = new QGroupBox( i18n( "Settings" ), frame );
@@ -118,7 +114,7 @@ void K3b::VideoCdRippingDialog::setupGui()
     setStartButtonText( i18n( "Start Ripping" ), i18n( "Starts extracting the selected VideoCd tracks" ) );
     // ----------------------------------------------------------------------------------
 
-    connect( m_editDirectory, SIGNAL(textChanged(const QString&)), this, SLOT(slotUpdateFreeSpace()) );
+    connect( m_editDirectory, SIGNAL(textChanged(QString)), this, SLOT(slotUpdateFreeSpace()) );
 
     m_labelNecessarySize ->setText( KIO::convertSize( m_videooptions ->getVideoCdSize() ) );
 }
@@ -131,7 +127,7 @@ void K3b::VideoCdRippingDialog::setupContextHelp()
     m_labelNecessarySize->setToolTip( i18n("Necessary space for extracted files") );
 
     m_ignoreExt->setToolTip( i18n("Ignore extended PSD") );
-    m_ignoreExt->setWhatsThis( i18n("<p>Ignore extended PSD (located in the ISO-9660 filesystem under `/EXT/PSD_X.VCD') and use the <em>standard</em> PSD.</p>") );
+    m_ignoreExt->setWhatsThis( i18n("<p>Ignore extended PSD (located in the ISO 9660 filesystem under `/EXT/PSD_X.VCD') and use the <em>standard</em> PSD.</p>") );
 
     m_sector2336->setToolTip( i18n("Assume a 2336-byte sector mode") );
     m_sector2336->setWhatsThis( i18n("<p>This option only makes sense if you are reading from a BIN CD disk image. This indicates to `vcdxrip' to assume a 2336-byte sector mode for image file.</p>"
@@ -153,7 +149,7 @@ void K3b::VideoCdRippingDialog::slotStartClicked()
     if( !d.exists() ) {
         if( KMessageBox::warningYesNo( this, i18n("Image folder '%1' does not exist. Do you want K3b to create it?", m_editDirectory->url().toLocalFile() ) )
             == KMessageBox::Yes ) {
-            if( !KStandardDirs::makeDir( m_editDirectory->url().toLocalFile() ) ) {
+            if( !QDir().mkpath( m_editDirectory->url().toLocalFile() ) ) {
                 KMessageBox::error( this, i18n("Failed to create folder '%1'.", m_editDirectory->url().toLocalFile() ) );
                 return;
             }
@@ -203,7 +199,7 @@ void K3b::VideoCdRippingDialog::slotFreeSpace(const QString&,
         textColor = colorScheme.foreground( KColorScheme::NegativeText ).color();
     else
         textColor = colorScheme.foreground( KColorScheme::NormalText ).color();
-    
+
     QPalette pal( m_labelNecessarySize->palette() );
     pal.setColor( m_labelNecessarySize->foregroundRole(), textColor );
     m_labelNecessarySize->setPalette( pal );
@@ -228,7 +224,7 @@ void K3b::VideoCdRippingDialog::slotUpdateFreeSpace()
 
 void K3b::VideoCdRippingDialog::loadSettings( const KConfigGroup& c )
 {
-    m_editDirectory ->setUrl( c.readEntry( "last ripping directory", K3b::defaultTempPath() ) );
+    m_editDirectory ->setUrl( QUrl::fromLocalFile( c.readEntry( "last ripping directory", K3b::defaultTempPath() ) ) );
     m_ignoreExt ->setChecked( c.readEntry( "ignore ext", false ) );
     m_sector2336 ->setChecked( c.readEntry( "sector 2336", false ) );
     m_extractXML ->setChecked( c.readEntry( "extract xml", false ) );
@@ -244,4 +240,4 @@ void K3b::VideoCdRippingDialog::saveSettings( KConfigGroup c )
     c.writeEntry( "extract xml", m_extractXML ->isChecked( ) );
 }
 
-#include "k3bvideocdrippingdialog.moc"
+
